@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
@@ -38,12 +38,12 @@
 #include "Statistics.hh"
 
 #ifdef HAVE_DISTRIBUTION
-#include "DistributionManager.hh"
+#  include "DistributionManager.hh"
 #endif
 
 #ifdef HAVE_DBUS
-#include "dbus/IDBus.hh"
-#include "DBusWorkrave.hh"
+#  include "dbus/IDBus.hh"
+#  include "DBusWorkrave.hh"
 #endif
 
 using namespace std;
@@ -56,21 +56,22 @@ using namespace std;
  *          windows.
  *  \param timer pointer to the interface of the timer that belongs to this break.
  */
-BreakControl::BreakControl(BreakId id, IApp *app, Timer *timer) :
-  break_id(id),
-  application(app),
-  break_timer(timer),
-  break_stage(STAGE_NONE),
-  reached_max_prelude(false),
-  prelude_time(0),
-  prelude_count(0),
-  postponable_count(0),
-  max_number_of_preludes(2),
-  fake_break(false),
-  fake_break_count(0),
-  user_abort(false),
-  delayed_abort(false),
-  break_hint(BREAK_HINT_NONE)
+BreakControl::BreakControl(BreakId id, const std::string &break_name, IApp *app, Timer *timer)
+  : break_id(id)
+  , break_name(break_name)
+  , application(app)
+  , break_timer(timer)
+  , break_stage{break_name + ".break.state", STAGE_NONE}
+  , reached_max_prelude(false)
+  , prelude_time(0)
+  , prelude_count{break_name + ".break.prelude_count", 0}
+  , forced_break{break_name + ".break.forced", false}
+  , max_number_of_preludes(2)
+  , fake_break{break_name + ".break.fake", false}
+  , fake_break_count(0)
+  , user_abort{break_name + ".break.user_abort", false}
+  , delayed_abort{break_name + ".break.delayed_abort", false}
+  , break_hint(BREAK_HINT_NONE)
 {
   assert(break_timer != NULL);
   assert(application != NULL);
@@ -78,14 +79,12 @@ BreakControl::BreakControl(BreakId id, IApp *app, Timer *timer) :
   core = Core::get_instance();
 }
 
-
 //! Destructor.
 BreakControl::~BreakControl()
 {
   application->hide_break_window();
 }
 
-
 //! Periodic heartbeat.
 void
 BreakControl::heartbeat()
@@ -199,7 +198,6 @@ BreakControl::heartbeat()
   TRACE_EXIT();
 }
 
-
 //! Initiates the specified break stage.
 void
 BreakControl::goto_stage(BreakStage stage)
@@ -221,13 +219,12 @@ BreakControl::goto_stage(BreakStage stage)
 
     case STAGE_NONE:
       {
-        // Teminate the break.
+        // Terminate the break.
         core->set_insensitive_mode_all_breaks(INSENSITIVE_MODE_IDLE_ON_LIMIT_REACHED);
         application->hide_break_window();
         core->defrost();
 
-        if (break_id == BREAK_ID_MICRO_BREAK &&
-            core->get_usage_mode() == USAGE_MODE_READING)
+        if (break_id == BREAK_ID_MICRO_BREAK && core->get_usage_mode() == USAGE_MODE_READING)
           {
             for (int i = BREAK_ID_MICRO_BREAK; i < BREAK_ID_SIZEOF; i++)
               {
@@ -283,7 +280,6 @@ BreakControl::goto_stage(BreakStage stage)
       {
         core->set_insensitive_mode_all_breaks(INSENSITIVE_MODE_FOLLOW_IDLE);
         prelude_count++;
-        postponable_count++;
         prelude_time = 0;
         application->hide_break_window();
 
@@ -341,7 +337,6 @@ BreakControl::goto_stage(BreakStage stage)
   TRACE_EXIT();
 }
 
-
 //! Updates the contents of the prelude window.
 void
 BreakControl::update_prelude_window()
@@ -349,7 +344,6 @@ BreakControl::update_prelude_window()
   application->set_break_progress(prelude_time, 29);
 }
 
-
 //! Updates the contents of the break window.
 void
 BreakControl::update_break_window()
@@ -363,7 +357,7 @@ BreakControl::update_break_window()
       idle = duration - fake_break_count;
       if (fake_break_count <= 0)
         {
-          stop_break(false);
+          stop_break();
         }
 
       fake_break_count--;
@@ -381,7 +375,6 @@ BreakControl::update_break_window()
   application->set_break_progress((int)idle, (int)duration);
 }
 
-
 //! Starts the break.
 void
 BreakControl::start_break()
@@ -427,7 +420,6 @@ BreakControl::start_break()
   TRACE_EXIT();
 }
 
-
 //! Starts the break without preludes.
 void
 BreakControl::force_start_break(BreakHint hint)
@@ -435,7 +427,7 @@ BreakControl::force_start_break(BreakHint hint)
   TRACE_ENTER_MSG("BreakControl::force_start_break", break_id);
 
   break_hint = hint;
-  forced_break = (break_hint & (BREAK_HINT_USER_INITIATED | BREAK_HINT_NATURAL_BREAK) ) != 0;
+  forced_break = (break_hint & (BREAK_HINT_USER_INITIATED | BREAK_HINT_NATURAL_BREAK)) != 0;
   fake_break = false;
   prelude_time = 0;
   user_abort = false;
@@ -465,30 +457,26 @@ BreakControl::force_start_break(BreakHint hint)
   TRACE_EXIT();
 }
 
-
 //! Stops the break.
 /*!
  *  Stopping a break will reset the "number of presented preludes" counter. So,
  *  wrt, "max-preludes", the break will start over when it comes back.
  */
 void
-BreakControl::stop_break(bool forced_stop)
+BreakControl::stop_break(bool reset_count)
 {
-  TRACE_ENTER_MSG("BreakControl::stop_break", forced_stop);
-
-  TRACE_MSG(" forced stop = " << break_id);
+  TRACE_ENTER_MSG("BreakControl::stop_break", break_id << " " << reset_count);
 
   suspend_break();
-  prelude_count = 0;
-  if (!forced_stop)
+
+  if (reset_count)
     {
-      postponable_count = 0;
+      prelude_count = 0;
     }
 
   TRACE_EXIT();
 }
 
-
 //! Suspend the break.
 /*!
  *  A suspended break will come back after snooze time. The number of times the
@@ -506,15 +494,13 @@ BreakControl::suspend_break()
   TRACE_EXIT();
 }
 
-
 //! Does the controller need a heartbeat?
 bool
 BreakControl::need_heartbeat()
 {
-  return ( break_stage != STAGE_NONE && break_stage != STAGE_SNOOZED );
+  return (break_stage != STAGE_NONE && break_stage != STAGE_SNOOZED);
 }
 
-
 //! Is the break active ?
 BreakControl::BreakState
 BreakControl::get_break_state()
@@ -542,6 +528,14 @@ BreakControl::is_taking()
   return break_stage == STAGE_TAKING;
 }
 
+bool
+BreakControl::is_max_preludes_reached() const
+{
+  TRACE_ENTER_MSG("BreakControl::is_max_preludes_reached",
+                  reached_max_prelude << " " << prelude_count << " " << max_number_of_preludes);
+  TRACE_EXIT();
+  return reached_max_prelude;
+}
 
 //! Postpones the active break.
 /*!
@@ -570,13 +564,12 @@ BreakControl::postpone_break()
       user_abort = true;
 
       // and stop the break.
-      stop_break(true);
+      stop_break();
 
       send_postponed();
     }
 }
 
-
 //! Skips the active break.
 /*!
  *  Skipping a break resets the break timer.
@@ -605,7 +598,7 @@ BreakControl::skip_break()
       stats->increment_break_counter(break_id, Statistics::STATS_BREAKVALUE_SKIPPED);
 
       // and stop the break.
-      stop_break(false);
+      stop_break();
 
       send_skipped();
     }
@@ -617,7 +610,6 @@ BreakControl::stop_prelude()
   delayed_abort = true;
 }
 
-
 //! Sets the maximum number of preludes.
 /*!
  *  After the maximum number of preludes, the break either stops bothering the
@@ -668,40 +660,32 @@ BreakControl::prelude_window_start()
   TRACE_EXIT();
 }
 
-
 bool
 BreakControl::action_notify()
 {
   TRACE_ENTER("GUI::action_notify");
   core->stop_prelude(break_id);
   TRACE_EXIT();
-  return false;   // false: kill listener.
+  return false; // false: kill listener.
 }
 
-
 //! Initializes this control to the specified state.
 void
 BreakControl::set_state_data(bool active, const BreakStateData &data)
 {
-  (void) active;
+  (void)active;
   TRACE_ENTER_MSG("BreakStateData::set_state_data", active);
 
-  TRACE_MSG("forced = " << data.forced_break <<
-            " prelude = " << data.prelude_count <<
-            " stage = " <<  data.break_stage <<
-            " final = " << reached_max_prelude <<
-            " total preludes = " << postponable_count <<
-            " time = " << data.prelude_time);
+  TRACE_MSG("forced = " << data.forced_break << " prelude = " << data.prelude_count << " stage = " << data.break_stage
+                        << " final = " << reached_max_prelude << " time = " << data.prelude_time);
 
   forced_break = data.forced_break;
   prelude_count = data.prelude_count;
   prelude_time = data.prelude_time;
-  postponable_count = data.postponable_count;
 
   TRACE_EXIT();
 }
 
-
 //! Returns the state of this control.
 void
 BreakControl::get_state_data(BreakStateData &data)
@@ -711,10 +695,8 @@ BreakControl::get_state_data(BreakStateData &data)
   data.break_stage = break_stage;
   data.reached_max_prelude = reached_max_prelude;
   data.prelude_time = prelude_time;
-  data.postponable_count = postponable_count;
 }
 
-
 //! Plays the specified sound unless action is user initiated.
 void
 BreakControl::post_event(CoreEvent event)
@@ -727,7 +709,6 @@ BreakControl::post_event(CoreEvent event)
   TRACE_EXIT();
 }
 
-
 void
 BreakControl::send_postponed()
 {
@@ -795,7 +776,7 @@ BreakControl::get_stage_text(BreakStage stage)
 void
 BreakControl::send_signal(BreakStage stage)
 {
-  (void) stage;
+  (void)stage;
 
 #ifdef HAVE_DBUS
   std::string progress = get_stage_text(stage);
