@@ -18,11 +18,11 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
-#ifdef PLATFORM_OS_OSX
-#include "OSXHelpers.hh"
+#ifdef PLATFORM_OS_MACOS
+#  include "MacOSHelpers.hh"
 #endif
 
 #include "debug.hh"
@@ -39,7 +39,6 @@
 using namespace std;
 using namespace workrave;
 
-
 // Constructs a new configurator.
 Configurator::Configurator(IConfigBackend *backend)
 {
@@ -51,21 +50,18 @@ Configurator::Configurator(IConfigBackend *backend)
     }
 }
 
-
 // Destructs the configurator.
 Configurator::~Configurator()
 {
   delete backend;
 }
 
-
 bool
 Configurator::load(std::string filename)
 {
   return backend->load(filename);
 }
 
-
 bool
 Configurator::save(std::string filename)
 {
@@ -75,7 +71,6 @@ Configurator::save(std::string filename)
   return ret;
 }
 
-
 bool
 Configurator::save()
 {
@@ -85,7 +80,6 @@ Configurator::save()
   return ret;
 }
 
-
 void
 Configurator::heartbeat()
 {
@@ -133,7 +127,6 @@ Configurator::heartbeat()
     }
 }
 
-
 void
 Configurator::set_delay(const std::string &key, int delay)
 {
@@ -151,15 +144,12 @@ Configurator::set_delay(const std::string &key, int delay)
     }
 }
 
-
-
 bool
 Configurator::remove_key(const std::string &key) const
 {
   return backend->remove_key(key);
 }
 
-
 bool
 Configurator::rename_key(const std::string &key, const std::string &new_key)
 {
@@ -186,7 +176,6 @@ Configurator::rename_key(const std::string &key, const std::string &new_key)
   return ok;
 }
 
-
 bool
 Configurator::set_value(const std::string &key, Variant &value, ConfigFlags flags)
 {
@@ -254,7 +243,6 @@ Configurator::set_value(const std::string &key, Variant &value, ConfigFlags flag
   return ret || skip;
 }
 
-
 bool
 Configurator::get_value(const std::string &key, VariantType type, Variant &out) const
 {
@@ -290,8 +278,6 @@ Configurator::get_value(const std::string &key, VariantType type, Variant &out)
   return ret;
 }
 
-
-
 bool
 Configurator::get_value(const std::string &key, std::string &out) const
 {
@@ -306,7 +292,6 @@ Configurator::get_value(const std::string &key, std::string &out) const
   return b;
 }
 
-
 bool
 Configurator::get_value(const std::string &key, bool &out) const
 {
@@ -321,7 +306,6 @@ Configurator::get_value(const std::string &key, bool &out) const
   return b;
 }
 
-
 bool
 Configurator::get_value(const std::string &key, int &out) const
 {
@@ -336,7 +320,6 @@ Configurator::get_value(const std::string &key, int &out) const
   return b;
 }
 
-
 bool
 Configurator::get_value(const std::string &key, double &out) const
 {
@@ -351,7 +334,6 @@ Configurator::get_value(const std::string &key, double &out) const
   return b;
 }
 
-
 bool
 Configurator::set_value(const std::string &key, const std::string &v, ConfigFlags flags)
 {
@@ -365,7 +347,6 @@ Configurator::set_value(const std::string &key, const std::string &v, ConfigFlag
   return ret;
 }
 
-
 bool
 Configurator::set_value(const std::string &key, const char *v, ConfigFlags flags)
 {
@@ -392,7 +373,6 @@ Configurator::set_value(const std::string &key, int v, ConfigFlags flags)
   return ret;
 }
 
-
 bool
 Configurator::set_value(const std::string &key, bool v, ConfigFlags flags)
 {
@@ -406,7 +386,6 @@ Configurator::set_value(const std::string &key, bool v, ConfigFlags flags)
   return ret;
 }
 
-
 bool
 Configurator::set_value(const std::string &key, double v, ConfigFlags flags)
 {
@@ -420,55 +399,47 @@ Configurator::set_value(const std::string &key, double v, ConfigFlags flags)
   return ret;
 }
 
-
 void
 Configurator::get_value_with_default(const string &key, int &out, const int def) const
 {
   bool b = get_value(key, out);
-  if (! b)
+  if (!b)
     {
       out = def;
       b = true;
     }
 }
 
-
-
 void
 Configurator::get_value_with_default(const string &key, bool &out, const bool def) const
 {
   bool b = get_value(key, out);
-  if (! b)
+  if (!b)
     {
       out = def;
     }
 }
 
-
 void
-Configurator::get_value_with_default(const string &key, string &out,
-                                const string def) const
+Configurator::get_value_with_default(const string &key, string &out, const string def) const
 {
   bool b = get_value(key, out);
-  if (! b)
+  if (!b)
     {
       out = def;
     }
 }
 
-
 void
-Configurator::get_value_with_default(const string &key, double &out,
-                                const double def) const
+Configurator::get_value_with_default(const string &key, double &out, const double def) const
 {
   bool b = get_value(key, out);
-  if (! b)
+  if (!b)
     {
       out = def;
     }
 }
 
-
 bool
 Configurator::get_typed_value(const std::string &key, std::string &t) const
 {
@@ -527,7 +498,6 @@ Configurator::get_typed_value(const std::string &key, std::string &t) const
   return b;
 }
 
-
 bool
 Configurator::set_typed_value(const std::string &key, const std::string &t)
 {
@@ -571,7 +541,6 @@ Configurator::set_typed_value(const std::string &key, const std::string &t)
   return true;
 }
 
-
 bool
 Configurator::add_listener(const std::string &key_prefix, IConfiguratorListener *listener)
 {
@@ -610,7 +579,6 @@ Configurator::add_listener(const std::string &key_prefix, IConfiguratorListener
   return ret;
 }
 
-
 bool
 Configurator::remove_listener(IConfiguratorListener *listener)
 {
@@ -634,7 +602,6 @@ Configurator::remove_listener(IConfiguratorListener *listener)
   return ret;
 }
 
-
 bool
 Configurator::remove_listener(const std::string &key_prefix, IConfiguratorListener *listener)
 {
@@ -663,7 +630,6 @@ Configurator::remove_listener(const std::string &key_prefix, IConfiguratorListen
   return ret;
 }
 
-
 bool
 Configurator::find_listener(IConfiguratorListener *listener, std::string &key) const
 {
@@ -713,7 +679,6 @@ Configurator::fire_configurator_event(const string &key)
   TRACE_EXIT();
 }
 
-
 //! Removes the leading '/'.
 void
 Configurator::strip_leading_slash(string &key) const
@@ -728,7 +693,6 @@ Configurator::strip_leading_slash(string &key) const
     }
 }
 
-
 //! Removes the trailing '/'.
 void
 Configurator::strip_trailing_slash(string &key) const
@@ -743,7 +707,6 @@ Configurator::strip_trailing_slash(string &key) const
     }
 }
 
-
 //! Adds add trailing '/' if it isn't there yet.
 void
 Configurator::add_trailing_slash(string &key) const
@@ -758,7 +721,6 @@ Configurator::add_trailing_slash(string &key) const
     }
 }
 
-
 bool
 Configurator::find_setting(const string &key, Setting &setting) const
 {
@@ -779,4 +741,3 @@ Configurator::config_changed_notify(const std::string &key)
 {
   fire_configurator_event(key);
 }
-
