@@ -1,6 +1,6 @@
 // Control.cc --- The main controller
 //
-// Copyright (C) 2001, 2002, 2003, 2005 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2001, 2002, 2003, 2005, 2010 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
@@ -29,17 +29,16 @@
 
 #include "PacketBuffer.hh"
 
-PacketBuffer::PacketBuffer() :
-  buffer(NULL),
-  read_ptr(NULL),
-  write_ptr(NULL),
-  buffer_size(0),
-  original_buffer(NULL),
-  original_buffer_size(0)
+PacketBuffer::PacketBuffer()
+  : buffer(NULL)
+  , read_ptr(NULL)
+  , write_ptr(NULL)
+  , buffer_size(0)
+  , original_buffer(NULL)
+  , original_buffer_size(0)
 {
 }
 
-
 PacketBuffer::~PacketBuffer()
 {
   narrow(0, -1);
@@ -70,11 +69,10 @@ PacketBuffer::create(int size)
   buffer_size = size;
 }
 
-
 void
 PacketBuffer::resize(int size)
 {
-  //TRACE_ENTER_MSG("PacketBuffer::resize", size);
+  // TRACE_ENTER_MSG("PacketBuffer::resize", size);
   narrow(0, -1);
 
   if (size == 0)
@@ -97,61 +95,62 @@ PacketBuffer::resize(int size)
           write_offset = size - 1;
         }
 
-      //TRACE_MSG(read_offset << " " << write_offset);
+      // TRACE_MSG(read_offset << " " << write_offset);
 
       buffer = g_renew(guint8, buffer, size);
 
-      //TRACE_MSG(buffer);
+      // TRACE_MSG(buffer);
 
       read_ptr = buffer + read_offset;
       write_ptr = buffer + write_offset;
       buffer_size = size;
     }
-  //TRACE_EXIT();
+  // TRACE_EXIT();
 }
 
 void
 PacketBuffer::grow(int size)
 {
-  //TRACE_ENTER_MSG("PacketBuffer::grow()", size)
+  // TRACE_ENTER_MSG("PacketBuffer::grow()", size)
   if (size < GROW_SIZE)
     {
       size = GROW_SIZE;
     }
 
   resize(buffer_size + size);
-  //TRACE_EXIT();
+  // TRACE_EXIT();
 }
 
-
-
 void
 PacketBuffer::pack(const guint8 *data, int size)
 {
   if (write_ptr + size + 2 >= buffer + buffer_size)
-  {
-    grow(size + 2);
-  }
+    {
+      grow(size + 2);
+    }
 
   pack_ushort(size);
   memcpy(write_ptr, data, size);
   write_ptr += size;
 }
 
-
-
 void
 PacketBuffer::pack_raw(const guint8 *data, int size)
 {
   if (write_ptr + size >= buffer + buffer_size)
-  {
-    grow(size);
-  }
+    {
+      grow(size);
+    }
 
   memcpy(write_ptr, data, size);
   write_ptr += size;
 }
 
+void
+PacketBuffer::pack_string(const std::string &data)
+{
+  pack_string(data.c_str());
+}
 
 void
 PacketBuffer::pack_string(const gchar *data)
@@ -163,9 +162,9 @@ PacketBuffer::pack_string(const gchar *data)
     }
 
   if (write_ptr + size + 2 >= buffer + buffer_size)
-  {
-    grow(size + 2);
-  }
+    {
+      grow(size + 2);
+    }
 
   pack_ushort(size);
 
@@ -186,9 +185,9 @@ PacketBuffer::poke_string(int pos, const gchar *data)
     }
 
   if (pos + size + 2 >= buffer_size)
-  {
-    grow(size + 2);
-  }
+    {
+      grow(size + 2);
+    }
 
   poke_ushort(pos, size);
 
@@ -198,7 +197,6 @@ PacketBuffer::poke_string(int pos, const gchar *data)
     }
 }
 
-
 void
 PacketBuffer::pack_ushort(guint16 data)
 {
@@ -214,7 +212,6 @@ PacketBuffer::pack_ushort(guint16 data)
   write_ptr += 2;
 }
 
-
 void
 PacketBuffer::pack_ulong(guint32 data)
 {
@@ -232,20 +229,18 @@ PacketBuffer::pack_ulong(guint32 data)
   write_ptr += 4;
 }
 
-
 void
 PacketBuffer::pack_byte(guint8 data)
 {
-  if (write_ptr + 1 >= buffer + buffer_size )
+  if (write_ptr + 1 >= buffer + buffer_size)
     {
       grow(1);
     }
 
   write_ptr[0] = data;
-  write_ptr ++;
+  write_ptr++;
 }
 
-
 void
 PacketBuffer::poke_byte(int pos, guint8 data)
 {
@@ -260,7 +255,7 @@ PacketBuffer::poke_byte(int pos, guint8 data)
 void
 PacketBuffer::poke_ushort(int pos, guint16 data)
 {
-  if (pos + 2 > buffer_size )
+  if (pos + 2 > buffer_size)
     {
       grow(pos + 2 - buffer_size);
     }
@@ -269,10 +264,8 @@ PacketBuffer::poke_ushort(int pos, guint16 data)
 
   w[pos] = ((data & 0x0000ff00) >> 8);
   w[pos + 1] = ((data & 0x000000ff));
-
 }
 
-
 int
 PacketBuffer::unpack(guint8 **data)
 {
@@ -296,7 +289,6 @@ PacketBuffer::unpack(guint8 **data)
   return size;
 }
 
-
 int
 PacketBuffer::unpack_raw(guint8 **data, int size)
 {
@@ -318,7 +310,6 @@ PacketBuffer::unpack_raw(guint8 **data, int size)
   return size;
 }
 
-
 gchar *
 PacketBuffer::unpack_string()
 {
@@ -344,7 +335,6 @@ PacketBuffer::unpack_string()
   return str;
 }
 
-
 guint32
 PacketBuffer::unpack_ulong()
 {
@@ -353,17 +343,13 @@ PacketBuffer::unpack_ulong()
 
   if (read_ptr + 4 <= buffer + buffer_size)
     {
-      ret = (((guint32)(r[0]) << 24) +
-             ((guint32)(r[1]) << 16) +
-             ((guint32)(r[2]) << 8) +
-             ((guint32)(r[3])));
-      read_ptr +=4;
+      ret = (((guint32)(r[0]) << 24) + ((guint32)(r[1]) << 16) + ((guint32)(r[2]) << 8) + ((guint32)(r[3])));
+      read_ptr += 4;
     }
 
   return ret;
 }
 
-
 guint16
 PacketBuffer::unpack_ushort()
 {
@@ -371,14 +357,13 @@ PacketBuffer::unpack_ushort()
   guint8 *r = (guint8 *)read_ptr;
 
   if (read_ptr + 2 <= write_ptr)
-  {
-    ret = (r[0] << 8) + r[1];
-    read_ptr += 2;
-  }
+    {
+      ret = (r[0] << 8) + r[1];
+      read_ptr += 2;
+    }
   return ret;
 }
 
-
 guint8
 PacketBuffer::unpack_byte()
 {
@@ -387,12 +372,11 @@ PacketBuffer::unpack_byte()
   if (read_ptr + 1 <= write_ptr)
     {
       ret = read_ptr[0];
-      read_ptr ++;
+      read_ptr++;
     }
   return ret;
 }
 
-
 int
 PacketBuffer::peek(int pos, guint8 **data)
 {
@@ -413,7 +397,6 @@ PacketBuffer::peek(int pos, guint8 **data)
   return size;
 }
 
-
 gchar *
 PacketBuffer::peek_string(int pos)
 {
@@ -434,24 +417,20 @@ PacketBuffer::peek_string(int pos)
   return str;
 }
 
-
-guint32 PacketBuffer::peek_ulong(int pos)
+guint32
+PacketBuffer::peek_ulong(int pos)
 {
   guint32 ret = 0;
   if (read_ptr + pos + 4 <= buffer + buffer_size)
     {
       guint8 *r = (guint8 *)read_ptr;
 
-      ret = (((guint32)(r[pos]) << 24) +
-             ((guint32)(r[pos + 1]) << 16) +
-             ((guint32)(r[pos + 2]) << 8) +
-             ((guint32)(r[pos + 3])));
+      ret = (((guint32)(r[pos]) << 24) + ((guint32)(r[pos + 1]) << 16) + ((guint32)(r[pos + 2]) << 8) + ((guint32)(r[pos + 3])));
     }
 
   return ret;
 }
 
-
 guint16
 PacketBuffer::peek_ushort(int pos)
 {
@@ -464,7 +443,6 @@ PacketBuffer::peek_ushort(int pos)
   return ret;
 }
 
-
 guint8
 PacketBuffer::peek_byte(int pos)
 {
@@ -476,7 +454,6 @@ PacketBuffer::peek_byte(int pos)
   return ret;
 }
 
-
 void
 PacketBuffer::reserve_size(int &pos)
 {
@@ -484,14 +461,12 @@ PacketBuffer::reserve_size(int &pos)
   pack_ushort(0);
 }
 
-
 void
 PacketBuffer::update_size(int pos)
 {
   poke_ushort(pos, bytes_written() - pos - 2);
 }
 
-
 int
 PacketBuffer::read_size(int &pos)
 {
@@ -502,7 +477,6 @@ PacketBuffer::read_size(int &pos)
   return size;
 }
 
-
 void
 PacketBuffer::skip_size(int &pos)
 {
@@ -510,7 +484,6 @@ PacketBuffer::skip_size(int &pos)
   skip(size);
 }
 
-
 void
 PacketBuffer::insert(int pos, int size)
 {
@@ -524,11 +497,10 @@ PacketBuffer::insert(int pos, int size)
     }
 }
 
-
 void
 PacketBuffer::narrow(int pos, int size)
 {
-  //TRACE_ENTER_MSG("PacketBuffer::narrow", pos << " " << size);
+  // TRACE_ENTER_MSG("PacketBuffer::narrow", pos << " " << size);
   if (pos == 0 && size == -1)
     {
       if (original_buffer != NULL)
@@ -562,5 +534,5 @@ PacketBuffer::narrow(int pos, int size)
       buffer_size = size;
       read_ptr = buffer;
     }
-  //TRACE_EXIT();
+  // TRACE_EXIT();
 }
