@@ -16,13 +16,14 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "MutterInputMonitor.hh"
 
 #include "debug.hh"
 #include "IInputMonitorListener.hh"
+#include "Diagnostics.hh"
 
 using namespace std;
 
@@ -35,6 +36,19 @@ MutterInputMonitor::MutterInputMonitor()
 
 MutterInputMonitor::~MutterInputMonitor()
 {
+  if (watch_id != 0)
+    {
+      g_bus_unwatch_name(watch_id);
+    }
+  if (idle_proxy != nullptr)
+    {
+      g_object_unref(idle_proxy);
+    }
+  if (session_proxy != nullptr)
+    {
+      g_object_unref(session_proxy);
+    }
+
   if (monitor_thread != NULL)
     {
       monitor_thread->wait();
@@ -55,6 +69,7 @@ MutterInputMonitor::init()
   if (result)
     {
       init_inhibitors();
+      init_service_monitor();
     }
 
   TRACE_EXIT();
@@ -81,7 +96,14 @@ MutterInputMonitor::init_idle_monitor()
       g_signal_connect(idle_proxy, "g-signal", G_CALLBACK(on_idle_monitor_signal), this);
 
       result = register_active_watch();
-      result = result && register_idle_watch();
+      if (result)
+        {
+          result = register_idle_watch();
+          if (!result)
+            {
+              unregister_active_watch();
+            }
+        }
 
       if (result)
         {
@@ -118,12 +140,49 @@ MutterInputMonitor::init_inhibitors()
 
       GVariant *v = g_dbus_proxy_get_cached_property(session_proxy, "InhibitedActions");
       inhibited = (g_variant_get_uint32(v) & GSM_INHIBITOR_FLAG_IDLE) != 0;
+      trace_inhibited = inhibited;
       TRACE_MSG("Inhibited:" << g_variant_get_uint32(v) << " " << inhibited);
       g_variant_unref(v);
     }
   TRACE_EXIT();
 }
 
+void
+MutterInputMonitor::on_bus_name_appeared(GDBusConnection *connection,
+                                         const gchar *name,
+                                         const gchar *name_owner,
+                                         gpointer user_data)
+{
+  TRACE_ENTER_MSG("MutterInputMonitor::on_bus_name_appeared", name);
+  (void)connection;
+  (void)name;
+  (void)name_owner;
+  auto *self = (MutterInputMonitor *)user_data;
+  if (self->watch_active != 0u)
+    {
+      self->register_active_watch();
+    }
+  if (self->watch_idle != 0u)
+    {
+      self->register_idle_watch();
+    }
+  TRACE_EXIT();
+}
+
+void
+MutterInputMonitor::init_service_monitor()
+{
+  TRACE_ENTER("MutterInputMonitor::init_service_monitor");
+  watch_id = g_bus_watch_name(G_BUS_TYPE_SESSION,
+                              "org.gnome.Mutter.IdleMonitor",
+                              G_BUS_NAME_WATCHER_FLAGS_NONE,
+                              on_bus_name_appeared,
+                              nullptr,
+                              this,
+                              nullptr);
+  TRACE_EXIT();
+}
+
 bool
 MutterInputMonitor::register_active_watch()
 {
@@ -133,7 +192,9 @@ MutterInputMonitor::register_active_watch()
 
   if (error == NULL)
     {
-      g_variant_get(reply, "(u)", &watch_active);
+      guint watch = 0;
+      g_variant_get(reply, "(u)", &watch);
+      watch_active = active;
       g_variant_unref(reply);
     }
   else
@@ -149,7 +210,8 @@ void
 MutterInputMonitor::register_active_watch_async()
 {
   TRACE_ENTER("MutterInputMonitor::register_active_watch_aync");
-  g_dbus_proxy_call(idle_proxy, "AddUserActiveWatch", NULL, G_DBUS_CALL_FLAGS_NONE, 10000, NULL, on_register_active_watch_reply, this);
+  g_dbus_proxy_call(
+    idle_proxy, "AddUserActiveWatch", NULL, G_DBUS_CALL_FLAGS_NONE, 10000, NULL, on_register_active_watch_reply, this);
   TRACE_EXIT();
 }
 
@@ -169,7 +231,9 @@ MutterInputMonitor::on_register_active_watch_reply(GObject *object, GAsyncResult
       return;
     }
 
-  g_variant_get(params, "(u)", &self->watch_active);
+  guint watch = 0;
+  g_variant_get(params, "(u)", &watch);
+  self->watch_active = watch;
   g_variant_unref(params);
 }
 
@@ -178,9 +242,10 @@ MutterInputMonitor::unregister_active_watch()
 {
   TRACE_ENTER("MutterInputMonitor::unregister_active_watch");
   GError *error = NULL;
-  if (watch_active != 0)
+  if (watch_active != 0u)
     {
-      GVariant *result = g_dbus_proxy_call_sync(idle_proxy, "RemoveWatch", g_variant_new("(u)", watch_active), G_DBUS_CALL_FLAGS_NONE, 10000, NULL, &error);
+      GVariant *result = g_dbus_proxy_call_sync(
+        idle_proxy, "RemoveWatch", g_variant_new("(u)", watch_active), G_DBUS_CALL_FLAGS_NONE, 10000, NULL, &error);
       if (error == NULL)
         {
           g_variant_unref(result);
@@ -200,9 +265,16 @@ void
 MutterInputMonitor::unregister_active_watch_async()
 {
   TRACE_ENTER("MutterInputMonitor::unregister_active_watch_async");
-  if (watch_active != 0)
+  if (watch_active != 0u)
     {
-      g_dbus_proxy_call(idle_proxy, "RemoveWatch", g_variant_new("(u)", watch_active), G_DBUS_CALL_FLAGS_NONE, 10000, NULL, on_unregister_active_watch_reply, this);
+      g_dbus_proxy_call(idle_proxy,
+                        "RemoveWatch",
+                        g_variant_new("(u)", watch_active),
+                        G_DBUS_CALL_FLAGS_NONE,
+                        10000,
+                        NULL,
+                        on_unregister_active_watch_reply,
+                        this);
     }
   TRACE_EXIT();
 }
@@ -231,11 +303,15 @@ MutterInputMonitor::register_idle_watch()
 {
   TRACE_ENTER("MutterInputMonitor::register_idle_watch");
   GError *error = NULL;
-  GVariant *reply = g_dbus_proxy_call_sync(idle_proxy, "AddIdleWatch", g_variant_new("(t)", 500), G_DBUS_CALL_FLAGS_NONE, 10000, NULL, &error);
+  GVariant *reply =
+    g_dbus_proxy_call_sync(idle_proxy, "AddIdleWatch", g_variant_new("(t)", 500), G_DBUS_CALL_FLAGS_NONE, 10000, NULL, &error);
 
   if (error == NULL)
     {
-      g_variant_get(reply, "(u)", &watch_idle);
+      guint watch = 0;
+      ;
+      g_variant_get(reply, "(u)", &watch);
+      watch_idle = watch;
       g_variant_unref(reply);
     }
   else
@@ -252,9 +328,10 @@ MutterInputMonitor::unregister_idle_watch()
 {
   TRACE_ENTER("MutterInputMonitor::unregister_idle_watch");
   GError *error = NULL;
-  if (watch_idle != 0)
+  if (watch_idle != 0u)
     {
-      GVariant *result = g_dbus_proxy_call_sync(idle_proxy, "RemoveWatch", g_variant_new("(u)", watch_idle), G_DBUS_CALL_FLAGS_NONE, 10000, NULL, &error);
+      GVariant *result = g_dbus_proxy_call_sync(
+        idle_proxy, "RemoveWatch", g_variant_new("(u)", watch_idle), G_DBUS_CALL_FLAGS_NONE, 10000, NULL, &error);
       if (error == NULL)
         {
           g_variant_unref(result);
@@ -286,7 +363,11 @@ MutterInputMonitor::terminate()
 }
 
 void
-MutterInputMonitor::on_idle_monitor_signal(GDBusProxy *proxy, gchar *sender_name, gchar *signal_name, GVariant *parameters, gpointer user_data)
+MutterInputMonitor::on_idle_monitor_signal(GDBusProxy *proxy,
+                                           gchar *sender_name,
+                                           gchar *signal_name,
+                                           GVariant *parameters,
+                                           gpointer user_data)
 {
   (void)proxy;
   (void)sender_name;
@@ -298,25 +379,35 @@ MutterInputMonitor::on_idle_monitor_signal(GDBusProxy *proxy, gchar *sender_name
       guint handlerID;
       g_variant_get(parameters, "(u)", &handlerID);
 
+      Diagnostics::instance().log("mutter: watch fired");
       if (handlerID == self->watch_active)
         {
           self->unregister_active_watch_async();
           self->active = true;
+          self->trace_active = true;
         }
       else if (handlerID == self->watch_idle)
         {
           self->register_active_watch_async();
           self->active = false;
+          self->trace_active = false;
+        }
+      else
+        {
+          Diagnostics::instance().log("mutter: unknown handler ID");
         }
     }
 }
 
 void
-MutterInputMonitor::on_session_manager_property_changed(GDBusProxy *session, GVariant *changed, char **invalidated, gpointer user_data)
+MutterInputMonitor::on_session_manager_property_changed(GDBusProxy *session,
+                                                        GVariant *changed,
+                                                        char **invalidated,
+                                                        gpointer user_data)
 {
   TRACE_ENTER("MutterInputMonitor::on_session_manager_property_changed");
-  (void) session;
-  (void) invalidated;
+  (void)session;
+  (void)invalidated;
 
   MutterInputMonitor *self = (MutterInputMonitor *)user_data;
 
@@ -324,6 +415,7 @@ MutterInputMonitor::on_session_manager_property_changed(GDBusProxy *session, GVa
   if (v != NULL)
     {
       self->inhibited = g_variant_get_uint32(v) & GSM_INHIBITOR_FLAG_IDLE;
+      self->trace_inhibited = self->inhibited;
       TRACE_MSG("Inhibited:" << g_variant_get_uint32(v));
       g_variant_unref(v);
     }
@@ -350,6 +442,7 @@ MutterInputMonitor::run()
 
               g_variant_get(reply, "(t)", &idletime);
               g_variant_unref(reply);
+              Diagnostics::instance().log("mutter: " + std::to_string(idletime));
               local_active = idletime < 1000;
             }
           else
