@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include <stdio.h>
@@ -34,35 +34,28 @@ W32Configurator::W32Configurator()
   key_root = "Software/Workrave";
 }
 
-
-W32Configurator::~W32Configurator()
-{
-}
-
+W32Configurator::~W32Configurator() {}
 
 bool
 W32Configurator::load(string filename)
 {
-  (void) filename;
+  (void)filename;
   return true;
 }
 
-
 bool
 W32Configurator::save(string filename)
 {
-  (void) filename;
+  (void)filename;
   return true;
 }
 
-
 bool
 W32Configurator::save()
 {
   return true;
 }
 
-
 bool
 W32Configurator::remove_key(const std::string &key)
 {
@@ -94,7 +87,6 @@ W32Configurator::remove_key(const std::string &key)
   return rc;
 }
 
-
 bool
 W32Configurator::get_config_value(const string &key, string &out) const
 {
@@ -117,39 +109,38 @@ W32Configurator::get_config_value(const string &key, string &out) const
       char *buffer;
 
       // get the size, in bytes, required for buffer
-      err = RegQueryValueExA( handle, c.c_str(), NULL, NULL, NULL, &size );
+      err = RegQueryValueExA(handle, c.c_str(), NULL, NULL, NULL, &size);
 
       if (err != ERROR_SUCCESS || !size)
         {
-          RegCloseKey( handle );
+          RegCloseKey(handle);
           TRACE_EXIT();
           return false;
         }
-      else if( !( buffer = (char *)malloc( size + 1 ) ) )
+      else if (!(buffer = (char *)malloc(size + 1)))
         {
-          RegCloseKey( handle );
+          RegCloseKey(handle);
           TRACE_EXIT();
           return false;
         }
 
-      err = RegQueryValueExA( handle, c.c_str(), NULL, &type, (LPBYTE)buffer, &size );
-      buffer[ size ] = '\0';
+      err = RegQueryValueExA(handle, c.c_str(), NULL, &type, (LPBYTE)buffer, &size);
+      buffer[size] = '\0';
 
-      if ( err == ERROR_SUCCESS && type == REG_SZ )
+      if (err == ERROR_SUCCESS && type == REG_SZ)
         {
           out = buffer;
           rc = true;
         }
 
-      RegCloseKey( handle );
-      free( buffer );
+      RegCloseKey(handle);
+      free(buffer);
     }
 
   TRACE_EXIT();
   return rc;
 }
 
-
 bool
 W32Configurator::get_config_value(const string &key, bool &out) const
 {
@@ -162,7 +153,6 @@ W32Configurator::get_config_value(const string &key, bool &out) const
   return rc;
 }
 
-
 //! Returns the value of the specified attribute
 /*!
  *  \retval true value successfully returned.
@@ -175,12 +165,11 @@ W32Configurator::get_config_value(const string &key, int &out) const
   bool rc = get_config_value(key, l);
   if (rc)
     {
-      out = (int) l;
+      out = (int)l;
     }
   return rc;
 }
 
-
 //! Returns the value of the specified attribute
 /*!
  *  \retval true value successfully returned.
@@ -199,7 +188,6 @@ W32Configurator::get_config_value(const string &key, long &out) const
   return rc;
 }
 
-
 //! Returns the value of the specified attribute
 /*!
  *  \retval true value successfully returned.
@@ -218,7 +206,6 @@ W32Configurator::get_config_value(const string &key, double &out) const
   return rc;
 }
 
-
 bool
 W32Configurator::set_config_value(const string &key, string v)
 {
@@ -233,12 +220,10 @@ W32Configurator::set_config_value(const string &key, string v)
   k = key_add_part(key_root, key);
   key_split(k, p, c);
   p32 = key_win32ify(p);
-  err = RegCreateKeyEx(HKEY_CURRENT_USER, p32.c_str(), 0,
-                       "", REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS,
-                       NULL, &handle, &disp);
+  err = RegCreateKeyEx(HKEY_CURRENT_USER, p32.c_str(), 0, "", REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS, NULL, &handle, &disp);
   if (err == ERROR_SUCCESS)
     {
-      err = RegSetValueEx(handle, c.c_str(), 0, REG_SZ, (BYTE *) v.c_str(), v.length()+1);
+      err = RegSetValueEx(handle, c.c_str(), 0, REG_SZ, (BYTE *)v.c_str(), v.length() + 1);
       RegCloseKey(handle);
       rc = (err == ERROR_SUCCESS);
     }
@@ -246,9 +231,6 @@ W32Configurator::set_config_value(const string &key, string v)
   return rc;
 }
 
-
-
-
 bool
 W32Configurator::set_config_value(const string &key, int v)
 {
@@ -273,7 +255,6 @@ W32Configurator::set_config_value(const string &key, bool v)
   return set_config_value(key, string(buf));
 }
 
-
 bool
 W32Configurator::set_config_value(const string &key, double v)
 {
@@ -282,8 +263,6 @@ W32Configurator::set_config_value(const string &key, double v)
   return set_config_value(key, string(buf));
 }
 
-
-
 string
 W32Configurator::key_add_part(string s, string t) const
 {
@@ -299,8 +278,8 @@ W32Configurator::key_split(const string &key, string &parent, string &child) con
   const char *slash = strrchr(s, '/');
   if (slash)
     {
-      parent = key.substr(0, slash-s);
-      child = slash+1;
+      parent = key.substr(0, slash - s);
+      child = slash + 1;
     }
   else
     {
@@ -324,7 +303,6 @@ W32Configurator::key_win32ify(const string &key) const
   return rc;
 }
 
-
 //! Removes the trailing '/'.
 void
 W32Configurator::strip_trailing_slash(string &key) const
@@ -339,7 +317,6 @@ W32Configurator::strip_trailing_slash(string &key) const
     }
 }
 
-
 //! Adds add trailing '/' if it isn't there yet.
 void
 W32Configurator::add_trailing_slash(string &key) const
