@@ -18,13 +18,13 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
 
-#ifdef PLATFORM_OS_OSX
-#include "OSXHelpers.hh"
+#ifdef PLATFORM_OS_MACOS
+#  include "MacOSHelpers.hh"
 #endif
 
 #include <cstdlib>
@@ -54,7 +54,6 @@ StringUtil::split(const string &in, const char delim, vector<std::string> &resul
   result.push_back(s);
 }
 
-
 string
 StringUtil::search_replace(const string &in, const string &search, const string &replace)
 {
