@@ -16,7 +16,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include <glib.h>
@@ -26,31 +26,31 @@
 #include "control.h"
 #include "timerbox.h"
 
-// TODO: Allow client to specify this name.
-#define  WORKRAVE_DBUS_NAME             "org.workrave.Applet"
+#define WORKRAVE_DBUS_NAME "org.workrave.Applet"
 
-#define  WORKRAVE_DBUS_APPLET_NAME      "org.workrave.Workrave"
-#define  WORKRAVE_DBUS_APPLET_IFACE     "org.workrave.AppletInterface"
-#define  WORKRAVE_DBUS_APPLET_OBJ       "/org/workrave/Workrave/UI"
+#define WORKRAVE_DBUS_APPLET_NAME "org.workrave.Workrave"
+#define WORKRAVE_DBUS_APPLET_IFACE "org.workrave.AppletInterface"
+#define WORKRAVE_DBUS_APPLET_OBJ "/org/workrave/Workrave/UI"
 
-#define  WORKRAVE_DBUS_CONTROL_NAME     "org.workrave.Workrave"
-#define  WORKRAVE_DBUS_CONTROL_IFACE    "org.workrave.ControlInterface"
-#define  WORKRAVE_DBUS_CONTROL_OBJ      "/org/workrave/Workrave/UI"
+#define WORKRAVE_DBUS_CONTROL_NAME "org.workrave.Workrave"
+#define WORKRAVE_DBUS_CONTROL_IFACE "org.workrave.ControlInterface"
+#define WORKRAVE_DBUS_CONTROL_OBJ "/org/workrave/Workrave/UI"
 
-#define  WORKRAVE_DBUS_CORE_NAME        "org.workrave.Workrave"
-#define  WORKRAVE_DBUS_CORE_IFACE       "org.workrave.CoreInterface"
-#define  WORKRAVE_DBUS_CORE_OBJ         "/org/workrave/Workrave/Core"
+#define WORKRAVE_DBUS_CORE_NAME "org.workrave.Workrave"
+#define WORKRAVE_DBUS_CORE_IFACE "org.workrave.CoreInterface"
+#define WORKRAVE_DBUS_CORE_OBJ "/org/workrave/Workrave/Core"
 
-enum {
+enum
+{
   MENU_CHANGED,
   ALIVE_CHANGED,
   LAST_SIGNAL
 };
 
-static guint
-signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = {0};
 
-struct _WorkraveTimerboxControlPrivate {
+struct _WorkraveTimerboxControlPrivate
+{
   GtkImage *image;
 
   GCancellable *applet_proxy_cancel;
@@ -80,7 +80,7 @@ struct _WorkraveTimerboxControlPrivate {
   WorkraveTimerbox *timerbox;
 };
 
-typedef struct _TimerData  TimerData;
+typedef struct _TimerData TimerData;
 struct _TimerData
 {
   char *bar_text;
@@ -93,25 +93,25 @@ struct _TimerData
   int bar_primary_max;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (WorkraveTimerboxControl, workrave_timerbox_control, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE(WorkraveTimerboxControl, workrave_timerbox_control, G_TYPE_OBJECT);
 
-static void workrave_timerbox_control_class_init (WorkraveTimerboxControlClass *klass);
-static void workrave_timerbox_control_init       (WorkraveTimerboxControl *self);
-static void workrave_timerbox_control_dispose    (GObject *object);
-static void workrave_timerbox_control_finalize   (GObject *object);
+static void workrave_timerbox_control_class_init(WorkraveTimerboxControlClass *klass);
+static void workrave_timerbox_control_init(WorkraveTimerboxControl *self);
+static void workrave_timerbox_control_dispose(GObject *object);
+static void workrave_timerbox_control_finalize(GObject *object);
 
-static void workrave_timerbox_control_check      (WorkraveTimerboxControl *self);
+static void workrave_timerbox_control_check(WorkraveTimerboxControl *self);
 static void workrave_timerbox_control_create_dbus(WorkraveTimerboxControl *self);
 
-static gboolean on_timer                  (gpointer user_data);
-static void on_dbus_applet_ready          (GObject *object, GAsyncResult *res, gpointer user_data);
-static void on_dbus_core_ready            (GObject *object, GAsyncResult *res, gpointer user_data);
-static void on_dbus_control_ready         (GObject *object, GAsyncResult *res, gpointer user_data);
-static void on_dbus_signal                (GDBusProxy *proxy, gchar *sender_name, gchar *signal_name, GVariant *parameters, gpointer user_data);
-static void on_update_timers              (WorkraveTimerboxControl *self, GVariant *parameters);
-static void on_bus_acquired               (GDBusConnection *connection, const gchar *name, gpointer user_data);
-static void on_workrave_appeared          (GDBusConnection *connection, const gchar *name, const gchar *name_owner, gpointer user_data);
-static void on_workrave_vanished          (GDBusConnection *connection, const gchar *name, gpointer user_data);
+static gboolean on_timer(gpointer user_data);
+static void on_dbus_applet_ready(GObject *object, GAsyncResult *res, gpointer user_data);
+static void on_dbus_core_ready(GObject *object, GAsyncResult *res, gpointer user_data);
+static void on_dbus_control_ready(GObject *object, GAsyncResult *res, gpointer user_data);
+static void on_dbus_signal(GDBusProxy *proxy, gchar *sender_name, gchar *signal_name, GVariant *parameters, gpointer user_data);
+static void on_update_timers(WorkraveTimerboxControl *self, GVariant *parameters);
+static void on_bus_acquired(GDBusConnection *connection, const gchar *name, gpointer user_data);
+static void on_workrave_appeared(GDBusConnection *connection, const gchar *name, const gchar *name_owner, gpointer user_data);
+static void on_workrave_vanished(GDBusConnection *connection, const gchar *name, gpointer user_data);
 
 GDBusProxy *
 workrave_timerbox_control_get_applet_proxy(WorkraveTimerboxControl *self)
@@ -166,7 +166,7 @@ workrave_timerbox_control_update_show_tray_icon(WorkraveTimerboxControl *self)
 
   if (priv->alive)
     {
-      switch(priv->tray_icon_mode)
+      switch (priv->tray_icon_mode)
         {
         case WORKRAVE_TIMERBOX_CONTROL_TRAY_ICON_MODE_ALWAYS:
           workrave_timerbox_set_force_icon(priv->timerbox, TRUE);
@@ -212,29 +212,27 @@ workrave_timerbox_control_class_init(WorkraveTimerboxControlClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS(klass);
 
-  signals[MENU_CHANGED] =
-    g_signal_new ("menu-changed",
-                  G_TYPE_FROM_CLASS(klass),
-                  G_SIGNAL_RUN_LAST | G_SIGNAL_MUST_COLLECT,
-                  0,
-                  NULL,
-                  NULL,
-                  g_cclosure_marshal_VOID__VARIANT,
-                  G_TYPE_NONE,
-                  1,
-                  G_TYPE_VARIANT);
+  signals[MENU_CHANGED] = g_signal_new("menu-changed",
+                                       G_TYPE_FROM_CLASS(klass),
+                                       G_SIGNAL_RUN_LAST | G_SIGNAL_MUST_COLLECT,
+                                       0,
+                                       NULL,
+                                       NULL,
+                                       g_cclosure_marshal_VOID__VARIANT,
+                                       G_TYPE_NONE,
+                                       1,
+                                       G_TYPE_VARIANT);
 
-  signals[ALIVE_CHANGED] =
-    g_signal_new ("alive-changed",
-                  G_TYPE_FROM_CLASS(klass),
-                  G_SIGNAL_RUN_LAST | G_SIGNAL_MUST_COLLECT,
-                  0,
-                  NULL,
-                  NULL,
-                  g_cclosure_marshal_VOID__BOOLEAN,
-                  G_TYPE_NONE,
-                  1,
-                  G_TYPE_BOOLEAN);
+  signals[ALIVE_CHANGED] = g_signal_new("alive-changed",
+                                        G_TYPE_FROM_CLASS(klass),
+                                        G_SIGNAL_RUN_LAST | G_SIGNAL_MUST_COLLECT,
+                                        0,
+                                        NULL,
+                                        NULL,
+                                        g_cclosure_marshal_VOID__BOOLEAN,
+                                        G_TYPE_NONE,
+                                        1,
+                                        G_TYPE_BOOLEAN);
 
   object_class->dispose = workrave_timerbox_control_dispose;
   object_class->finalize = workrave_timerbox_control_finalize;
@@ -328,26 +326,15 @@ workrave_timerbox_control_start(WorkraveTimerboxControl *self)
       return;
     }
 
-  priv->owner_id = g_bus_own_name(G_BUS_TYPE_SESSION,
-                                  WORKRAVE_DBUS_NAME,
-                                  G_BUS_NAME_OWNER_FLAGS_NONE,
-                                  on_bus_acquired,
-                                  NULL,
-                                  NULL,
-                                  self,
-                                  NULL);
+  priv->owner_id =
+    g_bus_own_name(G_BUS_TYPE_SESSION, WORKRAVE_DBUS_NAME, G_BUS_NAME_OWNER_FLAGS_NONE, on_bus_acquired, NULL, NULL, self, NULL);
 
   GError *error = NULL;
 
   if (error == NULL)
     {
-      GVariant *result = g_dbus_proxy_call_sync(priv->applet_proxy,
-                                                "Embed",
-                                                g_variant_new("(bs)", TRUE, WORKRAVE_DBUS_NAME),
-                                                G_DBUS_CALL_FLAGS_NONE,
-                                                -1,
-                                                NULL,
-                                                &error);
+      GVariant *result = g_dbus_proxy_call_sync(
+        priv->applet_proxy, "Embed", g_variant_new("(bs)", TRUE, WORKRAVE_DBUS_NAME), G_DBUS_CALL_FLAGS_NONE, -1, NULL, &error);
 
       if (error != NULL)
         {
@@ -364,13 +351,8 @@ workrave_timerbox_control_start(WorkraveTimerboxControl *self)
 
   if (error == NULL)
     {
-      GVariant *result = g_dbus_proxy_call_sync(priv->applet_proxy,
-                                                "GetTrayIconEnabled",
-                                                NULL,
-                                                G_DBUS_CALL_FLAGS_NONE,
-                                                -1,
-                                                NULL,
-                                                &error);
+      GVariant *result =
+        g_dbus_proxy_call_sync(priv->applet_proxy, "GetTrayIconEnabled", NULL, G_DBUS_CALL_FLAGS_NONE, -1, NULL, &error);
 
       if (error != NULL)
         {
@@ -388,13 +370,8 @@ workrave_timerbox_control_start(WorkraveTimerboxControl *self)
 
   if (error == NULL)
     {
-      GVariant *result = g_dbus_proxy_call_sync(priv->core_proxy,
-                                                "GetOperationMode",
-                                                NULL,
-                                                G_DBUS_CALL_FLAGS_NONE,
-                                                -1,
-                                                NULL,
-                                                &error);
+      GVariant *result =
+        g_dbus_proxy_call_sync(priv->core_proxy, "GetOperationMode", NULL, G_DBUS_CALL_FLAGS_NONE, -1, NULL, &error);
 
       if (error != NULL)
         {
@@ -414,7 +391,7 @@ workrave_timerbox_control_start(WorkraveTimerboxControl *self)
       priv->timer = g_timeout_add_seconds(10, on_timer, self);
       priv->alive = TRUE;
       priv->update_count = 0;
-      g_signal_emit (self, signals[ALIVE_CHANGED], 0, TRUE);
+      g_signal_emit(self, signals[ALIVE_CHANGED], 0, TRUE);
     }
   else
     {
@@ -451,11 +428,10 @@ workrave_timerbox_control_stop(WorkraveTimerboxControl *self)
       workrave_timerbox_control_update_show_tray_icon(self);
       workrave_timerbox_set_enabled(priv->timerbox, FALSE);
       workrave_timerbox_update(priv->timerbox, priv->image);
-      g_signal_emit (self, signals[ALIVE_CHANGED], 0, FALSE);
+      g_signal_emit(self, signals[ALIVE_CHANGED], 0, FALSE);
     }
 }
 
-
 static gboolean
 on_start_delay(gpointer user_data)
 {
@@ -472,10 +448,7 @@ static void
 workrave_timerbox_control_check(WorkraveTimerboxControl *self)
 {
   WorkraveTimerboxControlPrivate *priv = workrave_timerbox_control_get_instance_private(self);
-  if (priv->workrave_running &&
-      priv->applet_proxy != NULL &&
-      priv->core_proxy != NULL &&
-      priv->control_proxy != NULL)
+  if (priv->workrave_running && priv->applet_proxy != NULL && priv->core_proxy != NULL && priv->control_proxy != NULL)
     {
       // The Workrave interface may be started after the service becomes
       // available, so introduce a delay.
@@ -492,7 +465,7 @@ workrave_timerbox_control_create_dbus(WorkraveTimerboxControl *self)
   gboolean autostart = g_settings_get_boolean(settings, "autostart");
   g_object_unref(settings);
 
-  GDBusProxyFlags flags = autostart ?  : G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START;
+  GDBusProxyFlags flags = autostart ? 0 : G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START;
 
   priv->applet_proxy_cancel = g_cancellable_new();
   g_dbus_proxy_new_for_bus(G_BUS_TYPE_SESSION,
@@ -574,7 +547,6 @@ on_dbus_applet_ready(GObject *object, GAsyncResult *res, gpointer user_data)
   workrave_timerbox_control_check(self);
 }
 
-
 static void
 on_dbus_core_ready(GObject *object, GAsyncResult *res, gpointer user_data)
 {
@@ -646,7 +618,7 @@ on_dbus_signal(GDBusProxy *proxy, gchar *sender_name, gchar *signal_name, GVaria
 
   if (g_strcmp0(signal_name, "MenuUpdated") == 0)
     {
-      g_signal_emit (self, signals[MENU_CHANGED], 0, parameters);
+      g_signal_emit(self, signals[MENU_CHANGED], 0, parameters);
     }
 
   else if (g_strcmp0(signal_name, "TrayIconUpdated") == 0)
@@ -670,7 +642,7 @@ on_update_timers(WorkraveTimerboxControl *self, GVariant *parameters)
 {
   WorkraveTimerboxControlPrivate *priv = workrave_timerbox_control_get_instance_private(self);
 
-  if (! priv->alive)
+  if (!priv->alive)
     {
       workrave_timerbox_control_start(self);
     }
@@ -679,7 +651,8 @@ on_update_timers(WorkraveTimerboxControl *self, GVariant *parameters)
 
   TimerData td[BREAK_ID_SIZEOF];
 
-  g_variant_get(parameters, "((siuuuuuu)(siuuuuuu)(siuuuuuu))",
+  g_variant_get(parameters,
+                "((siuuuuuu)(siuuuuuu)(siuuuuuu))",
                 &td[BREAK_ID_MICRO_BREAK].bar_text,
                 &td[BREAK_ID_MICRO_BREAK].slot,
                 &td[BREAK_ID_MICRO_BREAK].bar_secondary_color,
@@ -703,8 +676,7 @@ on_update_timers(WorkraveTimerboxControl *self, GVariant *parameters)
                 &td[BREAK_ID_DAILY_LIMIT].bar_secondary_max,
                 &td[BREAK_ID_DAILY_LIMIT].bar_primary_color,
                 &td[BREAK_ID_DAILY_LIMIT].bar_primary_val,
-                &td[BREAK_ID_DAILY_LIMIT].bar_primary_max
-                );
+                &td[BREAK_ID_DAILY_LIMIT].bar_primary_max);
 
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
@@ -719,7 +691,8 @@ on_update_timers(WorkraveTimerboxControl *self, GVariant *parameters)
           workrave_timerbox_set_enabled(priv->timerbox, TRUE);
           workrave_timerbox_control_update_show_tray_icon(self);
           workrave_timebar_set_progress(timebar, td[i].bar_primary_val, td[i].bar_primary_max, td[i].bar_primary_color);
-          workrave_timebar_set_secondary_progress(timebar, td[i].bar_secondary_val, td[i].bar_secondary_max, td[i].bar_secondary_color);
+          workrave_timebar_set_secondary_progress(
+            timebar, td[i].bar_secondary_val, td[i].bar_secondary_max, td[i].bar_secondary_color);
           workrave_timebar_set_text(timebar, td[i].bar_text);
         }
     }
@@ -730,9 +703,9 @@ on_update_timers(WorkraveTimerboxControl *self, GVariant *parameters)
 static void
 on_bus_acquired(GDBusConnection *connection, const gchar *name, gpointer user_data)
 {
-  (void) connection;
-  (void) name;
-  (void) user_data;
+  (void)connection;
+  (void)name;
+  (void)user_data;
 }
 
 static void
