@@ -24,7 +24,7 @@
 #include "timebar.h"
 
 #ifdef USE_GTK2
-#include "compat.h"
+#  include "compat.h"
 #endif
 
 static void workrave_timerbox_class_init(WorkraveTimerboxClass *klass);
@@ -32,11 +32,14 @@ static void workrave_timerbox_init(WorkraveTimerbox *self);
 static void workrave_timerbox_dispose(GObject *gobject);
 static void workrave_timerbox_finalize(GObject *gobject);
 static void workrave_timerbox_set_property(GObject *gobject, guint property_id, const GValue *value, GParamSpec *pspec);
-static void workrave_timerbox_get_property (GObject *gobject, guint property_id, GValue *value, GParamSpec *pspec);
+static void workrave_timerbox_get_property(GObject *gobject, guint property_id, GValue *value, GParamSpec *pspec);
 
 static void workrave_timerbox_update_sheep(WorkraveTimerbox *self, cairo_t *cr);
 static void workrave_timerbox_update_time_bars(WorkraveTimerbox *self, cairo_t *cr);
 static void workrave_timerbox_compute_dimensions(WorkraveTimerbox *self, int *width, int *height);
+static GdkPixbuf *workrave_load_image(WorkraveTimerbox *self, const char *name);
+static void workrave_timerbox_init_images(WorkraveTimerbox *self);
+static void workrave_on_settings_changed(GSettings *gsettings, const gchar *key, void *user_data);
 
 enum
 {
@@ -44,7 +47,6 @@ enum
   PROP_NAME
 };
 
-
 const int PADDING_X = 2;
 const int PADDING_Y = 2;
 
@@ -61,10 +63,9 @@ struct _WorkraveTimerboxPrivate
   gboolean break_visible[BREAK_ID_SIZEOF];
   gboolean enabled;
   short filled_slots;
-  int width;
-  int height;
   gboolean force_icon;
   gchar *mode;
+  GSettings *settings;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE(WorkraveTimerbox, workrave_timerbox, G_TYPE_OBJECT);
@@ -86,42 +87,36 @@ workrave_timerbox_class_init(WorkraveTimerboxClass *klass)
                               "no-name-set" /* default value */,
                               G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE);
 
-  g_object_class_install_property(gobject_class,
-                                  PROP_NAME,
-                                  pspec);
-
+  g_object_class_install_property(gobject_class, PROP_NAME, pspec);
 }
 
-
 static void
 workrave_timerbox_init(WorkraveTimerbox *self)
 {
   WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
 
-  const char *icons[] = { "timer-micro-break.png", "timer-rest-break.png", "timer-daily.png" };
-  priv->normal_sheep_icon = gdk_pixbuf_new_from_file(WORKRAVE_PKGDATADIR "/images/workrave-icon-medium.png", NULL);
-  priv->quiet_sheep_icon = gdk_pixbuf_new_from_file(WORKRAVE_PKGDATADIR "/images/workrave-quiet-icon-medium.png", NULL);
-  priv->suspended_sheep_icon = gdk_pixbuf_new_from_file(WORKRAVE_PKGDATADIR "/images/workrave-suspended-icon-medium.png", NULL);
-
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
+
       priv->slot_to_time_bar[i] = g_object_new(WORKRAVE_TYPE_TIMEBAR, NULL);
-
-      GString *filename = g_string_new("");
-      g_string_printf(filename, "%s/images/%s", WORKRAVE_PKGDATADIR, icons[i]);
-      priv->break_to_icon[i] = gdk_pixbuf_new_from_file(filename->str, NULL);
-      g_string_free(filename, TRUE);
-
       priv->break_visible[i] = FALSE;
       priv->slot_to_break[i] = BREAK_ID_NONE;
       priv->break_to_slot[i] = -1;
+      priv->break_to_icon[i] = NULL;
     }
   priv->filled_slots = 0;
   priv->enabled = FALSE;
   priv->force_icon = FALSE;
   priv->mode = g_strdup("normal");
-}
+  priv->settings = g_settings_new("org.workrave.gui");
+  g_signal_connect(priv->settings, "changed", G_CALLBACK(workrave_on_settings_changed), self);
 
+  priv->normal_sheep_icon = NULL;
+  priv->quiet_sheep_icon = NULL;
+  priv->suspended_sheep_icon = NULL;
+
+  workrave_timerbox_init_images(self);
+}
 
 static void
 workrave_timerbox_dispose(GObject *gobject)
@@ -143,7 +138,6 @@ workrave_timerbox_dispose(GObject *gobject)
   G_OBJECT_CLASS(workrave_timerbox_parent_class)->dispose(gobject);
 }
 
-
 static void
 workrave_timerbox_finalize(GObject *gobject)
 {
@@ -151,7 +145,6 @@ workrave_timerbox_finalize(GObject *gobject)
   G_OBJECT_CLASS(workrave_timerbox_parent_class)->finalize(gobject);
 }
 
-
 static void
 workrave_timerbox_set_property(GObject *gobject, guint property_id, const GValue *value, GParamSpec *pspec)
 {
@@ -161,7 +154,7 @@ workrave_timerbox_set_property(GObject *gobject, guint property_id, const GValue
   switch (property_id)
     {
     case PROP_NAME:
-      g_free (priv->name);
+      g_free(priv->name);
       priv->name = g_value_dup_string(value);
       break;
 
@@ -171,7 +164,6 @@ workrave_timerbox_set_property(GObject *gobject, guint property_id, const GValue
     }
 }
 
-
 static void
 workrave_timerbox_get_property(GObject *gobject, guint property_id, GValue *value, GParamSpec *pspec)
 {
@@ -190,8 +182,7 @@ workrave_timerbox_get_property(GObject *gobject, guint property_id, GValue *valu
     }
 }
 
-
-void
+static void
 workrave_timerbox_update_sheep(WorkraveTimerbox *self, cairo_t *cr)
 {
   WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
@@ -214,8 +205,7 @@ workrave_timerbox_update_sheep(WorkraveTimerbox *self, cairo_t *cr)
     }
 }
 
-
-void
+static void
 workrave_timerbox_update_time_bars(WorkraveTimerbox *self, cairo_t *cr)
 {
   WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
@@ -225,11 +215,12 @@ workrave_timerbox_update_time_bars(WorkraveTimerbox *self, cairo_t *cr)
       int x = 0, y = 0;
       int bar_width, bar_height;
 
+
       if (priv->force_icon)
         {
           x += gdk_pixbuf_get_width(priv->normal_sheep_icon);
         }
-      
+
       workrave_timebar_get_dimensions(priv->slot_to_time_bar[0], &bar_width, &bar_height);
 
       int icon_width = gdk_pixbuf_get_width(priv->break_to_icon[0]);
@@ -256,9 +247,9 @@ workrave_timerbox_update_time_bars(WorkraveTimerbox *self, cairo_t *cr)
             {
               WorkraveTimebar *bar = priv->slot_to_time_bar[bid];
 
-              cairo_surface_t *surface =  cairo_get_target(cr);
-              cairo_surface_t *bar_surface = cairo_surface_create_for_rectangle(surface, x+icon_width+PADDING_X, y + bar_dy,
-                                                                                bar_width, bar_height);
+              cairo_surface_t *surface = cairo_get_target(cr);
+              cairo_surface_t *bar_surface =
+                cairo_surface_create_for_rectangle(surface, x + icon_width + PADDING_X, y + bar_dy, bar_width, bar_height);
               cairo_t *bar_cr = cairo_create(bar_surface);
               workrave_timebar_draw(bar, bar_cr);
               cairo_surface_destroy(bar_surface);
@@ -274,12 +265,11 @@ workrave_timerbox_update_time_bars(WorkraveTimerbox *self, cairo_t *cr)
     }
 }
 
-
-static
-void workrave_timerbox_compute_dimensions(WorkraveTimerbox *self, int *width, int *height)
+static void
+workrave_timerbox_compute_dimensions(WorkraveTimerbox *self, int *width, int *height)
 {
   WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
-  
+
   int bar_width, bar_height;
   workrave_timebar_get_dimensions(priv->slot_to_time_bar[0], &bar_width, &bar_height);
 
@@ -303,9 +293,8 @@ void workrave_timerbox_compute_dimensions(WorkraveTimerbox *self, int *width, in
     }
 }
 
-
 /**
- * workrave_timerbox_set_slot: 
+ * workrave_timerbox_set_slot:
  * @self: a @WorkraveTimerbox
  * @slot: slot to set
  * @brk: break to put in slot
@@ -343,10 +332,9 @@ workrave_timerbox_set_slot(WorkraveTimerbox *self, int slot, WorkraveBreakId brk
     }
 }
 
-
 /**
- * workrave_timerbox_update: 
- * @self: a @WorkraveTimerbox 
+ * workrave_timerbox_update:
+ * @self: a @WorkraveTimerbox
  * @image: a @GtkImage where the timerbox will be drawn into
  *
  */
@@ -406,10 +394,9 @@ workrave_timerbox_get_width(WorkraveTimerbox *self)
   return width;
 }
 
-
 /**
- * workrave_timerbox_get_height: 
- * @self: a @WorkraveTimerbox 
+ * workrave_timerbox_get_height:
+ * @self: a @WorkraveTimerbox
  *
  * Return value: The width of the @WorkraveTimerbox
  *
@@ -423,10 +410,9 @@ workrave_timerbox_get_height(WorkraveTimerbox *self)
   return height;
 }
 
-
 /**
- * workrave_timerbox_get_time_bar: 
- * @self: a @WorkraveTimerbox 
+ * workrave_timerbox_get_time_bar:
+ * @self: a @WorkraveTimerbox
  * @timer: the ID of the #WorkraveTimebar to return
  *
  * Return value: (transfer none): The @WorkraveTimebar of the specified timer
@@ -439,24 +425,22 @@ workrave_timerbox_get_time_bar(WorkraveTimerbox *self, WorkraveBreakId timer)
   return priv->slot_to_time_bar[timer];
 }
 
-
 /**
- * workrave_timerbox_set_enabled: 
- * @self: a @WorkraveTimerbox 
- * @enabled: 
+ * workrave_timerbox_set_enabled:
+ * @self: a @WorkraveTimerbox
+ * @enabled:
  *
  */
 void
 workrave_timerbox_set_enabled(WorkraveTimerbox *self, gboolean enabled)
 {
-    WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
-    priv->enabled = enabled;
+  WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
+  priv->enabled = enabled;
 }
 
-
 /**
- * workrave_timerbox_set_force_icon: 
- * @self: a @WorkraveTimerbox 
+ * workrave_timerbox_set_force_icon:
+ * @self: a @WorkraveTimerbox
  * @force: Whether the icon is always visible
  *
  */
@@ -468,9 +452,9 @@ workrave_timerbox_set_force_icon(WorkraveTimerbox *self, gboolean force)
 }
 
 /**
- * workrave_timerbox_set_operation_mode: 
- * @self: a @WorkraveTimerbox 
- * @mode: 
+ * workrave_timerbox_set_operation_mode:
+ * @self: a @WorkraveTimerbox
+ * @mode:
  *
  */
 void
@@ -480,3 +464,65 @@ workrave_timerbox_set_operation_mode(WorkraveTimerbox *self, gchar *mode)
   g_free(priv->mode);
   priv->mode = g_strdup(mode);
 }
+
+static GdkPixbuf *
+workrave_load_image(WorkraveTimerbox *self, const char *name)
+{
+  WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
+  GdkPixbuf *ret = NULL;
+
+  char *theme = g_settings_get_string(priv->settings, "icontheme");
+
+  char *file = g_build_filename(WORKRAVE_PKGDATADIR, "images", theme, name, NULL);
+  if (!g_file_test(file, G_FILE_TEST_EXISTS))
+    {
+      g_free(file);
+      file = g_build_filename(WORKRAVE_PKGDATADIR, "images", name, NULL);
+    }
+
+  ret = gdk_pixbuf_new_from_file(file, NULL);
+  g_free(file);
+
+  return ret;
+}
+
+static void
+workrave_timerbox_init_images(WorkraveTimerbox *self)
+{
+  WorkraveTimerboxPrivate *priv = workrave_timerbox_get_instance_private(self);
+
+  const char *icons[] = {"timer-micro-break.png", "timer-rest-break.png", "timer-daily.png"};
+
+  if (priv->normal_sheep_icon != NULL)
+    {
+      g_object_unref(priv->normal_sheep_icon);
+    }
+  if (priv->quiet_sheep_icon != NULL)
+    {
+      g_object_unref(priv->quiet_sheep_icon);
+    }
+  if (priv->suspended_sheep_icon != NULL)
+    {
+      g_object_unref(priv->suspended_sheep_icon);
+    }
+
+  priv->normal_sheep_icon = workrave_load_image(self, "workrave-icon-medium.png");
+  priv->quiet_sheep_icon = workrave_load_image(self, "workrave-quiet-icon-medium.png");
+  priv->suspended_sheep_icon = workrave_load_image(self, "workrave-suspended-icon-medium.png");
+
+  for (int i = 0; i < BREAK_ID_SIZEOF; i++)
+    {
+      if (priv->break_to_icon[i] != NULL)
+        {
+          g_object_unref(priv->break_to_icon[i]);
+        }
+      priv->break_to_icon[i] = workrave_load_image(self, icons[i]);
+    }
+}
+
+static void
+workrave_on_settings_changed(GSettings *gsettings, const gchar *key, void *user_data)
+{
+  WorkraveTimerbox *self = WORKRAVE_TIMERBOX(user_data);
+  workrave_timerbox_init_images(self);
+}
