@@ -16,7 +16,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "WorkraveApplet.h"
@@ -39,7 +39,7 @@ struct _WorkraveAppletPrivate
   gboolean alive;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (WorkraveApplet, workrave_applet, PANEL_TYPE_APPLET);
+G_DEFINE_TYPE_WITH_PRIVATE(WorkraveApplet, workrave_applet, PANEL_TYPE_APPLET);
 
 static void workrave_applet_fill(WorkraveApplet *applet);
 static void dbus_call_finish(GDBusProxy *proxy, GAsyncResult *res, gpointer user_data);
@@ -53,29 +53,26 @@ struct Menuitems
   char *dbuscmd;
 };
 
-static struct Menuitems menu_data[] =
-  {
-    { MENU_COMMAND_OPEN,                  TRUE,  TRUE,  "Open",           "OpenMain"          },
-    { MENU_COMMAND_PREFERENCES,           FALSE, FALSE, "Preferences",    "Preferences"       },
-    { MENU_COMMAND_EXERCISES,             FALSE, FALSE, "Exercises",      "Exercises"         },
-    { MENU_COMMAND_REST_BREAK,            FALSE, FALSE, "Restbreak",      "RestBreak"         },
-    { MENU_COMMAND_MODE_NORMAL,           FALSE, FALSE, "Normal",         NULL                },
-    { MENU_COMMAND_MODE_QUIET,            FALSE, FALSE, "Quiet",          NULL                },
-    { MENU_COMMAND_MODE_SUSPENDED,        FALSE, FALSE, "Suspended",      NULL                },
-    { MENU_COMMAND_NETWORK_CONNECT,       FALSE, FALSE, "Join",           "NetworkConnect"    },
-    { MENU_COMMAND_NETWORK_DISCONNECT,    FALSE, FALSE, "Disconnect",     "NetworkDisconnect" },
-    { MENU_COMMAND_NETWORK_LOG,           FALSE, FALSE, "ShowLog",        "NetworkLog"        },
-    { MENU_COMMAND_NETWORK_RECONNECT,     FALSE, FALSE, "Reconnect",      "NetworkReconnect"  },
-    { MENU_COMMAND_STATISTICS,            FALSE, FALSE, "Statistics",     "Statistics"        },
-    { MENU_COMMAND_ABOUT,                 FALSE, TRUE,  "About",          NULL                },
-    { MENU_COMMAND_MODE_READING,          FALSE, FALSE, "ReadingMode",    "ReadingMode"       },
-    { MENU_COMMAND_QUIT,                  FALSE, FALSE, "Quit",           "Quit"              }
-  };
+static struct Menuitems menu_data[] = {{MENU_COMMAND_OPEN, TRUE, TRUE, "Open", "OpenMain"},
+                                       {MENU_COMMAND_PREFERENCES, FALSE, FALSE, "Preferences", "Preferences"},
+                                       {MENU_COMMAND_EXERCISES, FALSE, FALSE, "Exercises", "Exercises"},
+                                       {MENU_COMMAND_REST_BREAK, FALSE, FALSE, "Restbreak", "RestBreak"},
+                                       {MENU_COMMAND_MODE_NORMAL, FALSE, FALSE, "Normal", NULL},
+                                       {MENU_COMMAND_MODE_QUIET, FALSE, FALSE, "Quiet", NULL},
+                                       {MENU_COMMAND_MODE_SUSPENDED, FALSE, FALSE, "Suspended", NULL},
+                                       {MENU_COMMAND_NETWORK_CONNECT, FALSE, FALSE, "Join", "NetworkConnect"},
+                                       {MENU_COMMAND_NETWORK_DISCONNECT, FALSE, FALSE, "Disconnect", "NetworkDisconnect"},
+                                       {MENU_COMMAND_NETWORK_LOG, FALSE, FALSE, "ShowLog", "NetworkLog"},
+                                       {MENU_COMMAND_NETWORK_RECONNECT, FALSE, FALSE, "Reconnect", "NetworkReconnect"},
+                                       {MENU_COMMAND_STATISTICS, FALSE, FALSE, "Statistics", "Statistics"},
+                                       {MENU_COMMAND_ABOUT, FALSE, TRUE, "About", NULL},
+                                       {MENU_COMMAND_MODE_READING, FALSE, FALSE, "ReadingMode", "ReadingMode"},
+                                       {MENU_COMMAND_QUIT, FALSE, FALSE, "Quit", "Quit"}};
 
 int
 lookup_menu_index_by_id(enum MenuCommand id)
 {
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       if (menu_data[i].id == id)
         {
@@ -89,7 +86,7 @@ lookup_menu_index_by_id(enum MenuCommand id)
 int
 lookup_menu_index_by_action(const char *action)
 {
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       if (g_strcmp0(menu_data[i].action, action) == 0)
         {
@@ -100,14 +97,15 @@ lookup_menu_index_by_action(const char *action)
   return -1;
 }
 
-void on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
+void
+on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
 {
   WorkraveApplet *applet = WORKRAVE_APPLET(user_data);
   applet->priv->alive = alive;
 
   if (!alive)
     {
-      for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+      for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
         {
           GtkAction *action = gtk_action_group_get_action(applet->priv->action_group, menu_data[i].action);
           gtk_action_set_visible(action, menu_data[i].visible_when_not_running);
@@ -115,19 +113,20 @@ void on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
     }
 }
 
-void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data)
+void
+on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data)
 {
   WorkraveApplet *applet = WORKRAVE_APPLET(user_data);
 
   GVariantIter *iter;
-  g_variant_get (parameters, "(a(sii))", &iter);
+  g_variant_get(parameters, "(a(sii))", &iter);
 
   char *text;
   int id;
   int flags;
 
-  gboolean visible[sizeof(menu_data)/sizeof(struct Menuitems)];
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  gboolean visible[sizeof(menu_data) / sizeof(struct Menuitems)];
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       visible[i] = menu_data[i].visible_when_not_running;
     }
@@ -142,8 +141,7 @@ void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data
 
       GtkAction *action = gtk_action_group_get_action(applet->priv->action_group, menu_data[index].action);
 
-      if (flags & MENU_ITEM_FLAG_SUBMENU_END ||
-          flags & MENU_ITEM_FLAG_SUBMENU_BEGIN)
+      if (flags & MENU_ITEM_FLAG_SUBMENU_END || flags & MENU_ITEM_FLAG_SUBMENU_BEGIN)
         {
           continue;
         }
@@ -157,16 +155,15 @@ void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data
         }
     }
 
-  g_variant_iter_free (iter);
+  g_variant_iter_free(iter);
 
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       GtkAction *action = gtk_action_group_get_action(applet->priv->action_group, menu_data[i].action);
       gtk_action_set_visible(action, visible[i]);
     }
 }
 
-
 static void
 dbus_call_finish(GDBusProxy *proxy, GAsyncResult *res, gpointer user_data)
 {
@@ -195,21 +192,31 @@ on_menu_about(GSimpleAction *action, GVariant *parameter, gpointer user_data)
   gtk_container_set_border_width(GTK_CONTAINER(about), 5);
 
   gtk_show_about_dialog(NULL,
-                        "name", "Workrave",
+                        "name",
+                        "Workrave",
 #ifdef GIT_VERSION
-                        "version", PACKAGE_VERSION "\n(" GIT_VERSION ")",
+                        "version",
+                        PACKAGE_VERSION "\n(" GIT_VERSION ")",
 #else
-                        "version", PACKAGE_VERSION,
+                        "version",
+                        PACKAGE_VERSION,
 #endif
-                        "copyright", workrave_copyright,
-                        "website", "http://www.workrave.org",
-                        "website_label", "www.workrave.org",
-                        "comments", _("This program assists in the prevention and recovery"
-                                      " of Repetitive Strain Injury (RSI)."),
-                        "translator-credits", workrave_translators,
-                        "authors", workrave_authors,
-                        "logo", pixbuf,
-                         NULL);
+                        "copyright",
+                        workrave_copyright,
+                        "website",
+                        "http://www.workrave.org",
+                        "website_label",
+                        "www.workrave.org",
+                        "comments",
+                        _("This program assists in the prevention and recovery"
+                          " of Repetitive Strain Injury (RSI)."),
+                        "translator-credits",
+                        workrave_translators,
+                        "authors",
+                        workrave_authors,
+                        "logo",
+                        pixbuf,
+                        NULL);
   g_object_unref(pixbuf);
 }
 
@@ -231,12 +238,11 @@ on_menu_command(GtkAction *action, WorkraveApplet *applet)
                         menu_data[index].autostart ? G_DBUS_CALL_FLAGS_NONE : G_DBUS_CALL_FLAGS_NO_AUTO_START,
                         -1,
                         NULL,
-                        (GAsyncReadyCallback) dbus_call_finish,
+                        (GAsyncReadyCallback)dbus_call_finish,
                         applet);
     }
 }
 
-
 static void
 on_menu_toggle(GtkAction *action, WorkraveApplet *applet)
 {
@@ -263,17 +269,16 @@ on_menu_toggle(GtkAction *action, WorkraveApplet *applet)
                         G_DBUS_CALL_FLAGS_NO_AUTO_START,
                         -1,
                         NULL,
-                        (GAsyncReadyCallback) dbus_call_finish,
+                        (GAsyncReadyCallback)dbus_call_finish,
                         &applet);
     }
 }
 
-
 static void
 on_menu_mode_changed(GtkRadioAction *action, GtkRadioAction *current, gpointer user_data)
 {
   WorkraveApplet *applet = WORKRAVE_APPLET(user_data);
-  const char *modes[] = { "normal", "suspended", "quiet" };
+  const char *modes[] = {"normal", "suspended", "quiet"};
   int mode = 0;
 
   if (GTK_IS_RADIO_ACTION(action))
@@ -293,87 +298,50 @@ on_menu_mode_changed(GtkRadioAction *action, GtkRadioAction *current, gpointer u
                             G_DBUS_CALL_FLAGS_NO_AUTO_START,
                             -1,
                             NULL,
-                            (GAsyncReadyCallback) dbus_call_finish,
+                            (GAsyncReadyCallback)dbus_call_finish,
                             &applet);
         }
     }
 }
 
+static const GtkActionEntry menu_actions[] = {
+  {"Open", GTK_STOCK_OPEN, N_("_Open"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-static const GtkActionEntry menu_actions [] = {
-  { "Open", GTK_STOCK_OPEN, N_("_Open"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Statistics", NULL, N_("_Statistics"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-  { "Statistics", NULL, N_("_Statistics"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-  { "Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Exercises", NULL, N_("_Exercises"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-  { "Exercises", NULL, N_("_Exercises"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Restbreak", NULL, N_("_Restbreak"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-  { "Restbreak", NULL, N_("_Restbreak"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Mode", NULL, N_("_Mode"), NULL, NULL, NULL},
 
-  { "Mode", NULL, N_("_Mode"),
-    NULL, NULL,
-    NULL },
+  {"Network", NULL, N_("_Network"), NULL, NULL, NULL},
 
-  { "Network", NULL, N_("_Network"),
-    NULL, NULL,
-    NULL },
+  {"Join", NULL, N_("_Join"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-  { "Join", NULL, N_("_Join"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Disconnect", NULL, N_("_Disconnect"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-  { "Disconnect", NULL, N_("_Disconnect"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Reconnect", NULL, N_("_Reconnect"), NULL, NULL, G_CALLBACK(on_menu_command)},
 
-  { "Reconnect", NULL, N_("_Reconnect"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"About", GTK_STOCK_ABOUT, N_("_About"), NULL, NULL, G_CALLBACK(on_menu_about)},
 
-  { "About", GTK_STOCK_ABOUT, N_("_About"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_about) },
-
-  { "Quit", GTK_STOCK_QUIT, N_("_Quit"),
-    NULL, NULL,
-    G_CALLBACK(on_menu_command) },
+  {"Quit", GTK_STOCK_QUIT, N_("_Quit"), NULL, NULL, G_CALLBACK(on_menu_command)},
 };
 
-
 static const GtkToggleActionEntry toggle_actions[] = {
-    { "ShowLog", NULL, N_("Show log"),
-      NULL, NULL,
-      G_CALLBACK(on_menu_toggle), FALSE },
+  {"ShowLog", NULL, N_("Show log"), NULL, NULL, G_CALLBACK(on_menu_toggle), FALSE},
 
-    { "ReadingMode", NULL, N_("Reading mode"),
-      NULL, NULL,
-      G_CALLBACK(on_menu_toggle), FALSE },
+  {"ReadingMode", NULL, N_("Reading mode"), NULL, NULL, G_CALLBACK(on_menu_toggle), FALSE},
 };
 
-
 static const GtkRadioActionEntry mode_actions[] = {
-    { "Normal", NULL, N_("Normal"),
-      NULL, NULL,
-      0 },
+  {"Normal", NULL, N_("Normal"), NULL, NULL, 0},
 
-    { "Suspended", NULL, N_("Suspended"),
-      NULL, NULL,
-      1 },
+  {"Suspended", NULL, N_("Suspended"), NULL, NULL, 1},
 
-    { "Quiet", NULL, N_("Quiet"),
-      NULL, NULL,
-      2 },
+  {"Quiet", NULL, N_("Quiet"), NULL, NULL, 2},
 };
 
 static gboolean
@@ -392,7 +360,7 @@ button_pressed(GtkWidget *widget, GdkEventButton *event, WorkraveApplet *applet)
                             G_DBUS_CALL_FLAGS_NO_AUTO_START,
                             -1,
                             NULL,
-                            (GAsyncReadyCallback) dbus_call_finish,
+                            (GAsyncReadyCallback)dbus_call_finish,
                             &applet);
           ret = TRUE;
         }
@@ -401,7 +369,6 @@ button_pressed(GtkWidget *widget, GdkEventButton *event, WorkraveApplet *applet)
   return ret;
 }
 
-
 static void
 workrave_applet_class_init(WorkraveAppletClass *class)
 {
@@ -413,28 +380,18 @@ workrave_applet_fill(WorkraveApplet *applet)
 {
   applet->priv->timerbox_control = g_object_new(WORKRAVE_TIMERBOX_CONTROL_TYPE, NULL);
   applet->priv->image = workrave_timerbox_control_get_image(applet->priv->timerbox_control);
-  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "menu-changed", G_CALLBACK(on_menu_changed),  applet);
-  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "alive-changed", G_CALLBACK(on_alive_changed),  applet);
+  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "menu-changed", G_CALLBACK(on_menu_changed), applet);
+  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "alive-changed", G_CALLBACK(on_alive_changed), applet);
 
   workrave_timerbox_control_set_tray_icon_visible_when_not_running(applet->priv->timerbox_control, TRUE);
-  workrave_timerbox_control_set_tray_icon_mode(applet->priv->timerbox_control, WORKRAVE_TIMERBOX_CONTROL_TRAY_ICON_MODE_ALWAYS);
+  workrave_timerbox_control_set_tray_icon_mode(applet->priv->timerbox_control, WORKRAVE_TIMERBOX_CONTROL_TRAY_ICON_MODE_FOLLOW);
 
   applet->priv->action_group = gtk_action_group_new("WorkraveAppletActions");
   gtk_action_group_set_translation_domain(applet->priv->action_group, GETTEXT_PACKAGE);
-  gtk_action_group_add_actions(applet->priv->action_group,
-                               menu_actions,
-                               G_N_ELEMENTS (menu_actions),
-                               applet);
-  gtk_action_group_add_toggle_actions(applet->priv->action_group,
-                                      toggle_actions,
-                                      G_N_ELEMENTS (toggle_actions),
-                                      applet);
-  gtk_action_group_add_radio_actions (applet->priv->action_group,
-                                      mode_actions,
-                                      G_N_ELEMENTS(mode_actions),
-                                      0,
-                                      G_CALLBACK(on_menu_mode_changed),
-                                      applet);
+  gtk_action_group_add_actions(applet->priv->action_group, menu_actions, G_N_ELEMENTS(menu_actions), applet);
+  gtk_action_group_add_toggle_actions(applet->priv->action_group, toggle_actions, G_N_ELEMENTS(toggle_actions), applet);
+  gtk_action_group_add_radio_actions(
+    applet->priv->action_group, mode_actions, G_N_ELEMENTS(mode_actions), 0, G_CALLBACK(on_menu_mode_changed), applet);
 
   gchar *ui_path = g_build_filename(WORKRAVE_UIDATADIR, "workrave-gnome-applet-menu.xml", NULL);
   panel_applet_setup_menu_from_file(PANEL_APPLET(applet), ui_path, applet->priv->action_group);
@@ -446,7 +403,7 @@ workrave_applet_fill(WorkraveApplet *applet)
   panel_applet_set_background_widget(PANEL_APPLET(applet), GTK_WIDGET(applet));
 
   gtk_widget_set_events(GTK_WIDGET(applet), gtk_widget_get_events(GTK_WIDGET(applet)) | GDK_BUTTON_PRESS_MASK);
-  g_signal_connect(G_OBJECT(applet), "button_press_event", G_CALLBACK(button_pressed),  applet);
+  g_signal_connect(G_OBJECT(applet), "button_press_event", G_CALLBACK(button_pressed), applet);
 
   gtk_container_add(GTK_CONTAINER(applet), GTK_WIDGET(applet->priv->image));
 
@@ -454,7 +411,6 @@ workrave_applet_fill(WorkraveApplet *applet)
   gtk_widget_show(GTK_WIDGET(applet));
 
   on_alive_changed(NULL, FALSE, applet);
-  // TODO: orientation?
 }
 
 static void
@@ -472,7 +428,6 @@ workrave_applet_init(WorkraveApplet *applet)
   workrave_applet_fill(applet);
 }
 
-
 static gboolean
 applet_factory(PanelApplet *applet, const gchar *iid, gpointer user_data)
 {
@@ -485,7 +440,4 @@ applet_factory(PanelApplet *applet, const gchar *iid, gpointer user_data)
   return FALSE;
 }
 
-PANEL_APPLET_OUT_PROCESS_FACTORY("WorkraveAppletFactory",
-                                 WORKRAVE_TYPE_APPLET,
-                                 applet_factory,
-                                 NULL)
+PANEL_APPLET_OUT_PROCESS_FACTORY("WorkraveAppletFactory", WORKRAVE_TYPE_APPLET, applet_factory, NULL)
