@@ -20,19 +20,19 @@
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
-#ifdef PLATFORM_OS_WIN32
-#include <gdk/gdkwin32.h>
-#include <shellapi.h>
+#ifdef PLATFORM_OS_WINDOWS
+#  include <gdk/gdkwin32.h>
+#  include <shellapi.h>
 #endif
 
 #include "nls.h"
 #include "debug.hh"
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#  include <unistd.h>
 #endif
 
 #include "MainWindow.hh"
@@ -46,12 +46,12 @@
 #include "TimerBoxGtkView.hh"
 #include "TimerBoxControl.hh"
 #include "GUI.hh"
-#include "Util.hh"
+#include "GtkUtil.hh"
 #include "Menus.hh"
 
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
 const char *WIN32_MAIN_CLASS_NAME = "Workrave";
-const UINT MYWM_TRAY_MESSAGE = WM_USER +0x100;
+const UINT MYWM_TRAY_MESSAGE = WM_USER + 0x100;
 #endif
 
 using namespace std;
@@ -61,24 +61,23 @@ using namespace std;
  *  \param gui the main GUI entry point.
  *  \param control Interface to the controller.
  */
-MainWindow::MainWindow() :
-  enabled(true),
-  can_close(true),
-  timer_box_control(NULL),
-  timer_box_view(NULL),
-  window_location(-1, -1),
-  window_head_location(-1, -1),
-  window_relocated_location(-1, -1)
+MainWindow::MainWindow()
+  : enabled(true)
+  , can_close(true)
+  , timer_box_control(NULL)
+  , timer_box_view(NULL)
+  , window_location(-1, -1)
+  , window_head_location(-1, -1)
+  , window_relocated_location(-1, -1)
 {
 #ifdef PLATFORM_OS_UNIX
   leader = NULL;
 #endif
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
   show_retry_count = 0;
 #endif
 }
 
-
 //! Destructor.
 MainWindow::~MainWindow()
 {
@@ -89,7 +88,7 @@ MainWindow::~MainWindow()
       visible_connection.disconnect();
     }
 
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
   if (timeout_connection.connected())
     {
       timeout_connection.disconnect();
@@ -97,7 +96,7 @@ MainWindow::~MainWindow()
 #endif
 
   delete timer_box_control;
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
   win32_exit();
 #endif
 #ifdef PLATFORM_OS_UNIX
@@ -110,10 +109,10 @@ MainWindow::~MainWindow()
 bool
 MainWindow::is_visible() const
 {
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
   const GtkWidget *window = Gtk::Widget::gobj();
   GdkWindow *gdk_window = gtk_widget_get_window(GTK_WIDGET(window));
-  HWND hwnd = (HWND) GDK_WINDOW_HWND(gdk_window);
+  HWND hwnd = (HWND)GDK_WINDOW_HWND(gdk_window);
   return IsWindowVisible(hwnd);
 #elif defined(HAVE_GTK3)
   return get_visible();
@@ -122,7 +121,6 @@ MainWindow::is_visible() const
 #endif
 }
 
-
 void
 MainWindow::toggle_window()
 {
@@ -140,7 +138,6 @@ MainWindow::toggle_window()
   TRACE_EXIT();
 }
 
-
 //! Opens the main window.
 void
 MainWindow::open_window()
@@ -148,7 +145,7 @@ MainWindow::open_window()
   TRACE_ENTER("MainWindow::open_window");
   if (timer_box_view->get_visible_count() > 0)
     {
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
       win32_show(true);
       show_all();
 #else
@@ -183,16 +180,14 @@ MainWindow::open_window()
   TRACE_EXIT();
 }
 
-
-
 //! Closes the main window.
 void
 MainWindow::close_window()
 {
   TRACE_ENTER("MainWindow::close_window");
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
   win32_show(false);
-#elif defined(PLATFORM_OS_OSX)
+#elif defined(PLATFORM_OS_MACOS)
   hide_all();
 #else
   if (can_close)
@@ -209,7 +204,6 @@ MainWindow::close_window()
   TRACE_EXIT();
 }
 
-
 void
 MainWindow::set_can_close(bool can_close)
 {
@@ -220,7 +214,7 @@ MainWindow::set_can_close(bool can_close)
   if (!enabled)
     {
       if (can_close)
-        { 
+        {
           TRACE_MSG("hide");
           hide();
         }
@@ -234,7 +228,6 @@ MainWindow::set_can_close(bool can_close)
   TRACE_EXIT();
 }
 
-
 //! Updates the main window.
 void
 MainWindow::update()
@@ -242,7 +235,6 @@ MainWindow::update()
   timer_box_control->update();
 }
 
-
 //! Initializes the main window.
 void
 MainWindow::init()
@@ -252,38 +244,34 @@ MainWindow::init()
   set_border_width(2);
   set_resizable(false);
 
-  list<Glib::RefPtr<Gdk::Pixbuf> > icons;
+  list<Glib::RefPtr<Gdk::Pixbuf>> icons;
 
   const char *icon_files[] = {
-                               "scalable/apps/workrave.svg",
-                               "16x16/apps/workrave.png",
-                               "24x24/apps/workrave.png",
-                               "32x32/apps/workrave.png",
-                               "48x48/apps/workrave.png",
-                               "64x64/apps/workrave.png",
-                               "96x96/apps/workrave.png",
-                               "128x128/apps/workrave.png",
-                               };
+#ifndef PLATFORM_OS_WINDOWS
+    // This causes a crash on windows
+    "scalable" G_DIR_SEPARATOR_S "workrave.svg",
+#endif
+    "16x16" G_DIR_SEPARATOR_S "workrave.png",
+    "24x24" G_DIR_SEPARATOR_S "workrave.png",
+    "32x32" G_DIR_SEPARATOR_S "workrave.png",
+    "48x48" G_DIR_SEPARATOR_S "workrave.png",
+    "64x64" G_DIR_SEPARATOR_S "workrave.png",
+    "96x96" G_DIR_SEPARATOR_S "workrave.png",
+    "128x128" G_DIR_SEPARATOR_S "workrave.png",
+  };
 
   for (unsigned int i = 0; i < sizeof(icon_files) / sizeof(char *); i++)
     {
-      string file = Util::complete_directory(icon_files[i], Util::SEARCH_PATH_IMAGES);
-
-      try
+      Glib::RefPtr<Gdk::Pixbuf> pixbuf = GtkUtil::create_pixbuf(icon_files[i]);
+      if (pixbuf)
         {
-          Glib::RefPtr<Gdk::Pixbuf> pixbuf = Gdk::Pixbuf::create_from_file(file);
-
-          TRACE_MSG(file << " size = " << pixbuf->get_width() << " " << pixbuf->get_height());
           icons.push_back(pixbuf);
         }
-      catch (...)
-        {
-        }
     }
 
-  Glib::ListHandle<Glib::RefPtr<Gdk::Pixbuf> > icon_list(icons);
+  Glib::ListHandle<Glib::RefPtr<Gdk::Pixbuf>> icon_list(icons);
   Gtk::Window::set_default_icon_list(icon_list);
-  //Gtk::Window::set_default_icon_name("workrave");
+  // Gtk::Window::set_default_icon_name("workrave");
 
   enabled = TimerBoxControl::is_enabled("main_window");
 
@@ -295,10 +283,9 @@ MainWindow::init()
   Gtk::EventBox *eventbox = new Gtk::EventBox;
   eventbox->set_visible_window(false);
   eventbox->set_events(eventbox->get_events() | Gdk::BUTTON_PRESS_MASK);
-#ifndef PLATFORM_OS_OSX
+#ifndef PLATFORM_OS_MACOS
   // No popup menu on OS X
-  eventbox->signal_button_press_event().connect(sigc::mem_fun(*this,
-                                                              &MainWindow::on_timer_view_button_press_event));
+  eventbox->signal_button_press_event().connect(sigc::mem_fun(*this, &MainWindow::on_timer_view_button_press_event));
 
 #endif
   eventbox->add(*timer_box_view);
@@ -310,9 +297,7 @@ MainWindow::init()
   Glib::RefPtr<Gdk::Window> window = get_window();
 
   // Window decorators
-  window->set_decorations(Gdk::DECOR_BORDER
-                          |Gdk::DECOR_TITLE
-                          |Gdk::DECOR_MENU);
+  window->set_decorations(Gdk::DECOR_BORDER | Gdk::DECOR_TITLE | Gdk::DECOR_MENU);
   // This used to be W32 only:
   //   window->set_functions(Gdk::FUNC_CLOSE|Gdk::FUNC_MOVE);
 
@@ -330,13 +315,13 @@ MainWindow::init()
   stick();
   setup();
 
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
 
   win32_init();
   set_gravity(Gdk::GRAVITY_STATIC);
   set_position(Gtk::WIN_POS_NONE);
 
-#ifdef HAVE_NOT_PROPER_SIZED_MAIN_WINDOW_ON_STARTUP
+#  ifdef HAVE_NOT_PROPER_SIZED_MAIN_WINDOW_ON_STARTUP
   // This is the proper code, see hacked code below.
   if (!enabled)
     {
@@ -350,23 +335,21 @@ MainWindow::init()
       move_to_start_position();
       show_all();
     }
-#else // Hack deprecated: Since GTK+ 2.10 no longer necessary
+#  else // Hack deprecated: Since GTK+ 2.10 no longer necessary
 
   // Hack: since GTK+ 2.2.4 the window is too wide, it incorporates room
   // for the "_ [ ] [X]" buttons somehow. This hack fixes just that.
   move(-1024, 0); // Move off-screen to reduce wide->narrow flickering
   show_all();
-  HWND hwnd = (HWND) GDK_WINDOW_HWND(window->gobj());
-  SetWindowPos(hwnd, NULL, 0, 0, 1, 1,
-               SWP_FRAMECHANGED|SWP_NOZORDER|SWP_NOACTIVATE
-               |SWP_NOOWNERZORDER|SWP_NOMOVE);
-  if (! enabled)
+  HWND hwnd = (HWND)GDK_WINDOW_HWND(window->gobj());
+  SetWindowPos(hwnd, NULL, 0, 0, 1, 1, SWP_FRAMECHANGED | SWP_NOZORDER | SWP_NOACTIVATE | SWP_NOOWNERZORDER | SWP_NOMOVE);
+  if (!enabled)
     {
       win32_show(false);
     }
   move_to_start_position();
   // (end of hack)
-#endif
+#  endif
 
 #else
   set_gravity(Gdk::GRAVITY_STATIC);
@@ -376,9 +359,9 @@ MainWindow::init()
 
   if (!enabled) //  || get_start_in_tray())
     {
-#ifndef PLATFORM_OS_OSX
+#  ifndef PLATFORM_OS_MACOS
       iconify();
-#endif
+#  endif
       close_window();
     }
 #endif
@@ -434,7 +417,6 @@ MainWindow::setup()
   TRACE_EXIT();
 }
 
-
 //! User has closed the main window.
 bool
 MainWindow::on_delete_event(GdkEventAny *)
@@ -443,11 +425,11 @@ MainWindow::on_delete_event(GdkEventAny *)
   IGUI *gui = GUI::get_instance();
   assert(gui != NULL);
 
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
   win32_show(false);
   closed_signal.emit();
   TimerBoxControl::set_enabled("main_window", false);
-#elif defined(PLATFORM_OS_OSX)
+#elif defined(PLATFORM_OS_MACOS)
   close_window();
   TimerBoxControl::set_enabled("main_window", false);
 #else
@@ -472,7 +454,7 @@ MainWindow::on_timer_view_button_press_event(GdkEventButton *event)
   TRACE_ENTER("MainWindow::on_timer_view_button_press_event");
   bool ret = false;
 
-  (void) event;
+  (void)event;
 
   if ((event->type == GDK_BUTTON_PRESS) && (event->button == 3))
     {
@@ -490,8 +472,7 @@ void
 MainWindow::config_changed_notify(const string &key)
 {
   TRACE_ENTER_MSG("MainWindow::config_changed_notify", key);
-  if (key != GUIConfig::CFG_KEY_MAIN_WINDOW_HEAD
-      && key != GUIConfig::CFG_KEY_MAIN_WINDOW_X
+  if (key != GUIConfig::CFG_KEY_MAIN_WINDOW_HEAD && key != GUIConfig::CFG_KEY_MAIN_WINDOW_X
       && key != GUIConfig::CFG_KEY_MAIN_WINDOW_Y)
     {
       setup();
@@ -499,8 +480,7 @@ MainWindow::config_changed_notify(const string &key)
   TRACE_EXIT();
 }
 
-
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
 void
 MainWindow::win32_show(bool b)
 {
@@ -510,16 +490,16 @@ MainWindow::win32_show(bool b)
   // Gtk's hide() seems to quit the program.
   GtkWidget *window = Gtk::Widget::gobj();
   GdkWindow *gdk_window = gtk_widget_get_window(window);
-  HWND hwnd = (HWND) GDK_WINDOW_HWND(gdk_window);
+  HWND hwnd = (HWND)GDK_WINDOW_HWND(gdk_window);
   ShowWindow(hwnd, b ? SW_SHOWNORMAL : SW_HIDE);
   visibility_changed_signal.emit();
-  
-	if (b)
-	  {
-		  present();
 
-		  if (hwnd != GetForegroundWindow())
-		    {
+  if (b)
+    {
+      present();
+
+      if (hwnd != GetForegroundWindow())
+        {
           if (show_retry_count == 0)
             {
               show_retry_count = 20;
@@ -553,46 +533,33 @@ MainWindow::win32_show_retry()
 {
   TRACE_ENTER("MainWindow::win32_show_retry");
   if (show_retry_count > 0)
-  {
-     TRACE_MSG("retry");
-     win32_show(true);
-  }
+    {
+      TRACE_MSG("retry");
+      win32_show(true);
+    }
   TRACE_EXIT();
   return false;
 }
 
-
-
 void
 MainWindow::win32_init()
 {
   TRACE_ENTER("MainWindow::win32_init");
 
-  win32_hinstance = (HINSTANCE) GetModuleHandle(NULL);
+  win32_hinstance = (HINSTANCE)GetModuleHandle(NULL);
 
-  WNDCLASSEX wclass =
-    {
-      sizeof(WNDCLASSEX),
-      0,
-      win32_window_proc,
-      0,
-      0,
-      win32_hinstance,
-      NULL,
-      NULL,
-      NULL,
-      NULL,
-      WIN32_MAIN_CLASS_NAME,
-      NULL
-    };
+  WNDCLASSEX wclass = {
+    sizeof(WNDCLASSEX), 0, win32_window_proc, 0, 0, win32_hinstance, NULL, NULL, NULL, NULL, WIN32_MAIN_CLASS_NAME, NULL};
   /* ATOM atom = */ RegisterClassEx(&wclass);
 
   win32_main_hwnd = CreateWindowEx(WS_EX_TOOLWINDOW,
                                    WIN32_MAIN_CLASS_NAME,
                                    "Workrave",
                                    WS_OVERLAPPED,
-                                   CW_USEDEFAULT, CW_USEDEFAULT,
-                                   CW_USEDEFAULT, CW_USEDEFAULT,
+                                   CW_USEDEFAULT,
+                                   CW_USEDEFAULT,
+                                   CW_USEDEFAULT,
+                                   CW_USEDEFAULT,
                                    (HWND)NULL,
                                    (HMENU)NULL,
                                    win32_hinstance,
@@ -600,13 +567,13 @@ MainWindow::win32_init()
   ShowWindow(win32_main_hwnd, SW_HIDE);
 
   // User data
-  SetWindowLong(win32_main_hwnd, GWL_USERDATA, (LONG) this);
+  SetWindowLong(win32_main_hwnd, GWL_USERDATA, (LONG)this);
 
   // Reassign ownership
   GtkWidget *window = Gtk::Widget::gobj();
   GdkWindow *gdk_window = gtk_widget_get_window(window);
-  HWND hwnd = (HWND) GDK_WINDOW_HWND(gdk_window);
-  SetWindowLong(hwnd, GWL_HWNDPARENT, (LONG) win32_main_hwnd);
+  HWND hwnd = (HWND)GDK_WINDOW_HWND(gdk_window);
+  SetWindowLong(hwnd, GWL_HWNDPARENT, (LONG)win32_main_hwnd);
 
   TRACE_EXIT();
 }
@@ -637,12 +604,10 @@ MainWindow::get_start_position(int &x, int &y, int &head)
   TRACE_EXIT();
 }
 
-
 void
 MainWindow::set_start_position(int x, int y, int head)
 {
-  TRACE_ENTER_MSG("MainWindow::set_start_position",
-                  x << " " << y << " " << head);
+  TRACE_ENTER_MSG("MainWindow::set_start_position", x << " " << y << " " << head);
   IConfigurator *cfg = CoreFactory::get_configurator();
   cfg->set_value(GUIConfig::CFG_KEY_MAIN_WINDOW_X, x);
   cfg->set_value(GUIConfig::CFG_KEY_MAIN_WINDOW_Y, y);
@@ -650,8 +615,6 @@ MainWindow::set_start_position(int x, int y, int head)
   TRACE_EXIT();
 }
 
-
-
 void
 MainWindow::move_to_start_position()
 {
@@ -690,10 +653,9 @@ MainWindow::move_to_start_position()
 bool
 MainWindow::on_configure_event(GdkEventConfigure *event)
 {
-  TRACE_ENTER_MSG("MainWindow::on_configure_event",
-                  event->x << " " << event->y);
+  TRACE_ENTER_MSG("MainWindow::on_configure_event", event->x << " " << event->y);
   locate_window(event);
-  bool ret =  Widget::on_configure_event(event);
+  bool ret = Widget::on_configure_event(event);
   TRACE_EXIT();
   return ret;
 }
@@ -705,7 +667,7 @@ MainWindow::locate_window(GdkEventConfigure *event)
   int x, y;
   int width, height;
 
-  (void) event;
+  (void)event;
 
   Glib::RefPtr<Gdk::Window> window = get_window();
   if ((window->get_state() & (Gdk::WINDOW_STATE_ICONIFIED | Gdk::WINDOW_STATE_WITHDRAWN)) != 0)
@@ -714,7 +676,7 @@ MainWindow::locate_window(GdkEventConfigure *event)
       return;
     }
 
-#ifndef PLATFORM_OS_WIN32
+#ifndef PLATFORM_OS_WINDOWS
   // Returns bogus results on windows...sometime.
   if (event != NULL)
     {
@@ -726,7 +688,7 @@ MainWindow::locate_window(GdkEventConfigure *event)
   else
 #endif
     {
-      (void) event;
+      (void)event;
 
       get_position(x, y);
 
@@ -735,8 +697,8 @@ MainWindow::locate_window(GdkEventConfigure *event)
       GtkRequisition natural_size;
       get_preferred_size(min_size, natural_size);
 #else
-      GtkRequisition min_size;
-      on_size_request(&min_size);
+    GtkRequisition min_size;
+    on_size_request(&min_size);
 #endif
 
       width = min_size.width;
@@ -752,8 +714,7 @@ MainWindow::locate_window(GdkEventConfigure *event)
       return;
     }
 
-  if (x != window_relocated_location.get_x() ||
-      y != window_relocated_location.get_y())
+  if (x != window_relocated_location.get_x() || y != window_relocated_location.get_y())
     {
       window_location.set_x(x);
       window_location.set_y(y);
@@ -778,7 +739,6 @@ MainWindow::locate_window(GdkEventConfigure *event)
   TRACE_EXIT();
 }
 
-
 void
 MainWindow::relocate_window(int width, int height)
 {
@@ -842,11 +802,10 @@ MainWindow::relocate_window(int width, int height)
   TRACE_EXIT();
 }
 
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
 
 LRESULT CALLBACK
-MainWindow::win32_window_proc(HWND hwnd, UINT uMsg, WPARAM wParam,
-                              LPARAM lParam)
+MainWindow::win32_window_proc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
 {
   TRACE_ENTER_MSG("MainWindow::win32_window_proc", uMsg << " " << wParam);
   TRACE_EXIT();
@@ -854,7 +813,6 @@ MainWindow::win32_window_proc(HWND hwnd, UINT uMsg, WPARAM wParam,
 }
 #endif
 
-
 void
 MainWindow::on_visibility_changed()
 {
