@@ -1,6 +1,4 @@
-// PreferencesDialog.cc --- Preferences dialog
-//
-// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2002 - 2020 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -18,7 +16,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
@@ -27,7 +25,7 @@
 #include "debug.hh"
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#  include <unistd.h>
 #endif
 #include <assert.h>
 
@@ -53,42 +51,40 @@
 #include "GUI.hh"
 #include "GUIConfig.hh"
 #include "DataConnector.hh"
+#include "Menus.hh"
 
 #include "CoreFactory.hh"
 #include "CoreConfig.hh"
 #include "IConfigurator.hh"
 
 #ifdef HAVE_DISTRIBUTION
-#include "NetworkPreferencePage.hh"
+#  include "NetworkPreferencePage.hh"
 #endif
 
 #ifndef WR_CHECK_VERSION
-#define WR_CHECK_VERSION(comp,major,minor,micro)   \
-    (comp##_MAJOR_VERSION > (major) || \
-     (comp##_MAJOR_VERSION == (major) && comp##_MINOR_VERSION > (minor)) || \
-     (comp##_MAJOR_VERSION == (major) && comp##_MINOR_VERSION == (minor) && \
-      comp##_MICRO_VERSION >= (micro)))
+#  define WR_CHECK_VERSION(comp, major, minor, micro)                                                      \
+    (comp##_MAJOR_VERSION > (major) || (comp##_MAJOR_VERSION == (major) && comp##_MINOR_VERSION > (minor)) \
+     || (comp##_MAJOR_VERSION == (major) && comp##_MINOR_VERSION == (minor) && comp##_MICRO_VERSION >= (micro)))
 #endif
 
-
 #define RUNKEY "Software\\Microsoft\\Windows\\CurrentVersion\\Run"
 
 using namespace std;
 
 PreferencesDialog::PreferencesDialog()
-  : HigDialog(_("Preferences"), false, false),
-    sound_button(NULL),
-    block_button(NULL),
-    sound_theme_button(NULL),
-    connector(NULL),
-    sound_volume_scale(NULL),
-    sound_play_button(NULL),
-    fsbutton(NULL),
-    filefilter(NULL)
-#ifdef PLATFORM_OS_WIN32
-    ,
-    sensitivity_adjustment(3, 0, 100),
-    sensitivity_box(NULL)
+  : HigDialog(_("Preferences"), false, false)
+  , sound_button(NULL)
+  , block_button(NULL)
+  , sound_theme_button(NULL)
+  , icon_theme_button(NULL)
+  , connector(NULL)
+  , sound_volume_scale(NULL)
+  , sound_play_button(NULL)
+  , fsbutton(NULL)
+  , filefilter(NULL)
+#ifdef PLATFORM_OS_WINDOWS
+  , sensitivity_adjustment(3, 0, 100)
+  , sensitivity_box(NULL)
 #endif
 {
   TRACE_ENTER("PreferencesDialog::PreferencesDialog");
@@ -100,7 +96,7 @@ PreferencesDialog::PreferencesDialog()
   Gtk::Widget *timer_page = Gtk::manage(create_timer_page());
   Gtk::Notebook *gui_page = Gtk::manage(new Gtk::Notebook());
 
-#if !defined(PLATFORM_OS_OSX)
+#if !defined(PLATFORM_OS_MACOS)
   Gtk::Widget *gui_general_page = Gtk::manage(create_gui_page());
   gui_page->append_page(*gui_general_page, _("General"));
 #endif
@@ -113,7 +109,7 @@ PreferencesDialog::PreferencesDialog()
   Gtk::Widget *gui_mainwindow_page = Gtk::manage(create_mainwindow_page());
   gui_page->append_page(*gui_mainwindow_page, _("Status Window"));
 
-#if !defined(PLATFORM_OS_OSX)
+#if !defined(PLATFORM_OS_MACOS)
   Gtk::Widget *gui_applet_page = Gtk::manage(create_applet_page());
   gui_page->append_page(*gui_applet_page, _("Applet"));
 #endif
@@ -141,14 +137,13 @@ PreferencesDialog::PreferencesDialog()
   TRACE_EXIT();
 }
 
-
 //! Destructor.
 PreferencesDialog::~PreferencesDialog()
 {
   TRACE_ENTER("PreferencesDialog::~PreferencesDialog");
 
 #if defined(HAVE_LANGUAGE_SELECTION)
-  const Gtk::TreeModel::iterator& iter = languages_combo.get_active();
+  const Gtk::TreeModel::iterator &iter = languages_combo.get_active();
   const Gtk::TreeModel::Row row = *iter;
   const Glib::ustring code = row[languages_columns.code];
 
@@ -156,7 +151,7 @@ PreferencesDialog::~PreferencesDialog()
 #endif
 
   ICore *core = CoreFactory::get_core();
-  core->remove_operation_mode_override( "preferences" );
+  core->remove_operation_mode_override("preferences");
 
   delete connector;
 #ifndef HAVE_GTK3
@@ -165,8 +160,6 @@ PreferencesDialog::~PreferencesDialog()
   TRACE_EXIT();
 }
 
-
-
 Gtk::Widget *
 PreferencesDialog::create_gui_page()
 {
@@ -195,8 +188,7 @@ PreferencesDialog::create_gui_page()
       block_idx = 2;
     }
   block_button->set_active(block_idx);
-  block_button->signal_changed()
-    .connect(sigc::mem_fun(*this, &PreferencesDialog::on_block_changed));
+  block_button->signal_changed().connect(sigc::mem_fun(*this, &PreferencesDialog::on_block_changed));
 
   // Options
   HigCategoryPanel *panel = Gtk::manage(new HigCategoryPanel(_("Options")));
@@ -243,18 +235,17 @@ PreferencesDialog::create_gui_page()
         }
 
       string txt = languages_current_locale[code].language_name;
-      if( txt.empty() )
-      {
+      if (txt.empty())
+        {
           txt = "Unrecognized language: (" + code + ")";
-      }
+        }
       else if (languages_current_locale[code].country_name != "")
         {
           txt += " (" + languages_current_locale[code].country_name + ")";
         }
       row[languages_columns.current] = txt;
 
-      if (languages_current_locale[code].language_name !=
-          languages_native_locale[code].language_name)
+      if (languages_current_locale[code].language_name != languages_native_locale[code].language_name)
         {
           txt = languages_native_locale[code].language_name;
           if (languages_native_locale[code].country_name != "")
@@ -274,19 +265,13 @@ PreferencesDialog::create_gui_page()
     }
 
   languages_model->set_sort_column(languages_columns.current, Gtk::SORT_ASCENDING);
- 	languages_model->set_sort_func (languages_columns.current,
-                                  sigc::mem_fun(*this,
-                                                &PreferencesDialog::on_cell_data_compare));
+  languages_model->set_sort_func(languages_columns.current, sigc::mem_fun(*this, &PreferencesDialog::on_cell_data_compare));
 
   languages_combo.pack_start(current_cellrenderer, true);
   languages_combo.pack_start(native_cellrenderer, false);
 
-  languages_combo.set_cell_data_func(native_cellrenderer,
-                                     sigc::mem_fun(*this,
-                                                   &PreferencesDialog::on_native_cell_data));
-  languages_combo.set_cell_data_func(current_cellrenderer,
-                                     sigc::mem_fun(*this,
-                                                   &PreferencesDialog::on_current_cell_data));
+  languages_combo.set_cell_data_func(native_cellrenderer, sigc::mem_fun(*this, &PreferencesDialog::on_native_cell_data));
+  languages_combo.set_cell_data_func(current_cellrenderer, sigc::mem_fun(*this, &PreferencesDialog::on_current_cell_data));
 
   languages_combo.set_active(selected);
 
@@ -295,13 +280,13 @@ PreferencesDialog::create_gui_page()
 
   bool show_autostart = false;
 
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
   show_autostart = true;
 #elif defined(PLATFORM_OS_UNIX)
   const char *desktop = g_getenv("XDG_CURRENT_DESKTOP");
   show_autostart = (g_strcmp0(desktop, "Unity") == 0);
-#endif  
-  
+#endif
+
   if (show_autostart)
     {
       Gtk::Label *autostart_lab = Gtk::manage(GtkUtil::create_label(_("Start Workrave on logon"), false));
@@ -309,10 +294,10 @@ PreferencesDialog::create_gui_page()
       autostart_cb->add(*autostart_lab);
       autostart_cb->signal_toggled().connect(sigc::mem_fun(*this, &PreferencesDialog::on_autostart_toggled));
       panel->add_widget(*autostart_cb);
-      
+
       connector->connect(GUIConfig::CFG_KEY_AUTOSTART, dc::wrap(autostart_cb));
-      
-#if defined(PLATFORM_OS_WIN32)
+
+#if defined(PLATFORM_OS_WINDOWS)
       char value[MAX_PATH];
       bool rc = Util::registry_get_value(RUNKEY, "Workrave", value);
       autostart_cb->set_active(rc);
@@ -325,12 +310,17 @@ PreferencesDialog::create_gui_page()
   connector->connect(GUIConfig::CFG_KEY_TRAYICON_ENABLED, dc::wrap(trayicon_cb));
 
   panel->add_widget(*trayicon_cb, false, false);
-  
+
+  update_icon_theme_combo();
+  if (icon_theme_button != NULL)
+    {
+      panel->add_label(_("Icon Theme:"), *icon_theme_button);
+    }
+
   panel->set_border_width(12);
   return panel;
 }
 
-
 Gtk::Widget *
 PreferencesDialog::create_sounds_page()
 {
@@ -341,7 +331,7 @@ PreferencesDialog::create_sounds_page()
   panel->pack_start(*hig, false, false, 0);
 
   // Sound types
-  sound_button  = Gtk::manage(new Gtk::ComboBoxText());
+  sound_button = Gtk::manage(new Gtk::ComboBoxText());
 #if GTKMM_CHECK_VERSION(2, 24, 0)
   sound_button->append(_("No sounds"));
   sound_button->append(_("Play sounds using sound card"));
@@ -352,7 +342,7 @@ PreferencesDialog::create_sounds_page()
   sound_button->append_text(_("Play sounds using built-in speaker"));
 #endif
   int idx;
-  if (! SoundPlayer::is_enabled())
+  if (!SoundPlayer::is_enabled())
     idx = 0;
   else
     {
@@ -370,7 +360,7 @@ PreferencesDialog::create_sounds_page()
   if (snd->capability(SOUND_CAP_VOLUME))
     {
       // Volume
-      sound_volume_scale =  Gtk::manage(new Gtk:: HScale(0.0, 100.0, 0.0));
+      sound_volume_scale = Gtk::manage(new Gtk::HScale(0.0, 100.0, 0.0));
       sound_volume_scale->set_increments(1.0, 5.0);
       connector->connect(SoundPlayer::CFG_KEY_SOUND_VOLUME, dc::wrap(sound_volume_scale->get_adjustment()));
 
@@ -382,8 +372,7 @@ PreferencesDialog::create_sounds_page()
   if (snd->capability(SOUND_CAP_MUTE))
     {
       // Volume
-      mute_cb = Gtk::manage(new Gtk::CheckButton
-                            (_("Mute sounds during rest break and daily limit")));
+      mute_cb = Gtk::manage(new Gtk::CheckButton(_("Mute sounds during rest break and daily limit")));
 
       connector->connect(SoundPlayer::CFG_KEY_SOUND_MUTE, dc::wrap(mute_cb));
 
@@ -396,9 +385,9 @@ PreferencesDialog::create_sounds_page()
       hig = Gtk::manage(new HigCategoryPanel(_("Sound Events"), true));
       panel->pack_start(*hig, true, true, 0);
 
-      sound_theme_button  = Gtk::manage(new Gtk::ComboBoxText());
+      sound_theme_button = Gtk::manage(new Gtk::ComboBoxText());
 
-      update_theme_selection();
+      update_sound_theme_selection();
 
       sound_theme_button->signal_changed().connect(sigc::mem_fun(*this, &PreferencesDialog::on_sound_theme_changed));
       hig->add_label(_("Sound Theme:"), *sound_theme_button);
@@ -427,7 +416,8 @@ PreferencesDialog::create_sounds_page()
       int cols_count = sound_treeview.append_column_editable(_("Play"), sound_model.enabled);
       Gtk::TreeViewColumn *column = sound_treeview.get_column(cols_count - 1);
 
-      Gtk::CellRendererToggle *cell = dynamic_cast<Gtk::CellRendererToggle*>(sound_treeview.get_column_cell_renderer(cols_count - 1));
+      Gtk::CellRendererToggle *cell =
+        dynamic_cast<Gtk::CellRendererToggle *>(sound_treeview.get_column_cell_renderer(cols_count - 1));
 
       cols_count = sound_treeview.append_column(_("Event"), sound_model.description);
       column = sound_treeview.get_column(cols_count - 1);
@@ -445,9 +435,7 @@ PreferencesDialog::create_sounds_page()
       sound_play_button = Gtk::manage(new Gtk::Button(_("Play")));
       hbox->pack_start(*sound_play_button, false, false, 0);
 
-      fsbutton = Gtk::manage(new Gtk::FileChooserButton(_("Choose a sound"),
-                                                   Gtk::FILE_CHOOSER_ACTION_OPEN
-                                                   ));
+      fsbutton = Gtk::manage(new Gtk::FileChooserButton(_("Choose a sound"), Gtk::FILE_CHOOSER_ACTION_OPEN));
 
       hbox->pack_start(*fsbutton, true, true, 0);
 
@@ -458,7 +446,7 @@ PreferencesDialog::create_sounds_page()
 #endif
 
       filefilter->set_name(_("Wavefiles"));
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
       filefilter->add_pattern("*.wav");
 #else
       filefilter->add_mime_type("audio/x-wav");
@@ -478,26 +466,20 @@ PreferencesDialog::create_sounds_page()
       selector_playbutton->show();
       fsbutton->set_extra_widget(*selector_hbox);
 
-      cell->signal_toggled().connect(sigc::mem_fun(*this,
-                                                   &PreferencesDialog::on_sound_enabled));
+      cell->signal_toggled().connect(sigc::mem_fun(*this, &PreferencesDialog::on_sound_enabled));
 
-      sound_play_button->signal_clicked().connect(sigc::mem_fun(*this,
-                                                                &PreferencesDialog::on_sound_play));
+      sound_play_button->signal_clicked().connect(sigc::mem_fun(*this, &PreferencesDialog::on_sound_play));
 
-      selector_playbutton->signal_clicked().connect(sigc::mem_fun(*this,
-                                                                  &PreferencesDialog::on_sound_filechooser_play));
+      selector_playbutton->signal_clicked().connect(sigc::mem_fun(*this, &PreferencesDialog::on_sound_filechooser_play));
 
-#if WR_CHECK_VERSION(GTKMM,2,22,0)
-      fsbutton->signal_file_set().connect(sigc::mem_fun(*this,
-                                                                 &PreferencesDialog::on_sound_filechooser_select));
+#if WR_CHECK_VERSION(GTKMM, 2, 22, 0)
+      fsbutton->signal_file_set().connect(sigc::mem_fun(*this, &PreferencesDialog::on_sound_filechooser_select));
 #else
-      fsbutton->signal_selection_changed().connect(sigc::mem_fun(*this,
-                                                                 &PreferencesDialog::on_sound_filechooser_select));
+      fsbutton->signal_selection_changed().connect(sigc::mem_fun(*this, &PreferencesDialog::on_sound_filechooser_select));
 #endif
 
       Glib::RefPtr<Gtk::TreeSelection> selection = sound_treeview.get_selection();
-      selection->signal_changed().connect(sigc::mem_fun(*this,
-                                                        &PreferencesDialog::on_sound_events_changed));
+      selection->signal_changed().connect(sigc::mem_fun(*this, &PreferencesDialog::on_sound_events_changed));
 
       Gtk::TreeModel::iterator iter = sound_store->children().begin();
       if (iter)
@@ -512,22 +494,18 @@ PreferencesDialog::create_sounds_page()
   return panel;
 }
 
-
 Gtk::Widget *
 PreferencesDialog::create_timer_page()
 {
   // Timers page
   Gtk::Notebook *tnotebook = Gtk::manage(new Gtk::Notebook());
-  tnotebook->set_tab_pos (Gtk::POS_TOP);
-  Glib::RefPtr<Gtk::SizeGroup> hsize_group
-    = Gtk::SizeGroup::create(Gtk::SIZE_GROUP_HORIZONTAL);
-  Glib::RefPtr<Gtk::SizeGroup> vsize_group
-    = Gtk::SizeGroup::create(Gtk::SIZE_GROUP_VERTICAL);
+  tnotebook->set_tab_pos(Gtk::POS_TOP);
+  Glib::RefPtr<Gtk::SizeGroup> hsize_group = Gtk::SizeGroup::create(Gtk::SIZE_GROUP_HORIZONTAL);
+  Glib::RefPtr<Gtk::SizeGroup> vsize_group = Gtk::SizeGroup::create(Gtk::SIZE_GROUP_VERTICAL);
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
       // Label
-      Gtk::Widget *box = Gtk::manage(GtkUtil::create_label_for_break
-                                ((BreakId) i));
+      Gtk::Widget *box = Gtk::manage(GtkUtil::create_label_for_break((BreakId)i));
       TimerPreferencesPanel *tp = Gtk::manage(new TimerPreferencesPanel(BreakId(i), hsize_group, vsize_group));
       box->show_all();
 #ifdef HAVE_GTK3
@@ -537,38 +515,41 @@ PreferencesDialog::create_timer_page()
 #endif
     }
 
-#if defined(PLATFORM_OS_WIN32)
   Gtk::Widget *box = Gtk::manage(GtkUtil::create_label("Monitoring", false));
   Gtk::Widget *monitoring_page = create_monitoring_page();
 
 #ifdef HAVE_GTK3
-  tnotebook->append_page(*monitoring_page , *box);
+  tnotebook->append_page(*monitoring_page, *box);
 #else
   tnotebook->pages().push_back(Gtk::Notebook_Helpers::TabElem(*monitoring_page, *box));
-#endif
 #endif
 
   return tnotebook;
 }
 
-#if defined(PLATFORM_OS_WIN32)
 Gtk::Widget *
 PreferencesDialog::create_monitoring_page()
 {
   Gtk::VBox *panel = Gtk::manage(new Gtk::VBox(false, 6));
   panel->set_border_width(12);
 
+#if defined(PLATFORM_OS_WINDOWS)
   Gtk::Label *monitor_type_lab = Gtk::manage(GtkUtil::create_label(_("Use alternate monitor"), false));
   monitor_type_cb = Gtk::manage(new Gtk::CheckButton());
   monitor_type_cb->add(*monitor_type_lab);
   monitor_type_cb->signal_toggled().connect(sigc::mem_fun(*this, &PreferencesDialog::on_monitor_type_toggled));
   panel->pack_start(*monitor_type_cb, false, false, 0);
 
-  Gtk::Label *monitor_type_help = Gtk::manage(GtkUtil::create_label(_("Enable this option if Workrave fails to detect when you are using your computer"), false));
-  panel->pack_start(*monitor_type_help, false, false, 0);
+  Gtk::Label *monitor_type_help1 =
+    Gtk::manage(GtkUtil::create_label(_("Enable this option if Workrave fails to detect when you are using your computer"), false));
+  panel->pack_start(*monitor_type_help1, false, false, 0);
+  Gtk::Label *monitor_type_help2 =
+    Gtk::manage(GtkUtil::create_label(_("Workrave needs to be restarted manually after changing this setting"), false));
+  panel->pack_start(*monitor_type_help2, false, false, 0);
 
   sensitivity_box = Gtk::manage(new Gtk::HBox());
-  Gtk::Widget *sensitivity_lab = Gtk::manage(GtkUtil::create_label_with_tooltip(_("Mouse sensitivity:"), _("Number of pixels the mouse should move before it is considered activity.")));
+  Gtk::Widget *sensitivity_lab = Gtk::manage(GtkUtil::create_label_with_tooltip(
+    _("Mouse sensitivity:"), _("Number of pixels the mouse should move before it is considered activity.")));
   Gtk::SpinButton *sensitivity_spin = Gtk::manage(new Gtk::SpinButton(sensitivity_adjustment));
   sensitivity_box->pack_start(*sensitivity_lab, false, false, 0);
   sensitivity_box->pack_start(*sensitivity_spin, false, false, 0);
@@ -577,19 +558,20 @@ PreferencesDialog::create_monitoring_page()
   connector->connect(CoreConfig::CFG_KEY_MONITOR_SENSITIVITY, dc::wrap(&sensitivity_adjustment));
 
   string monitor_type;
-  CoreFactory::get_configurator()->get_value_with_default("advanced/monitor",
-                                                          monitor_type,
-                                                          "default");
+  CoreFactory::get_configurator()->get_value_with_default("advanced/monitor", monitor_type, "default");
 
   monitor_type_cb->set_active(monitor_type != "default");
 
   sensitivity_box->set_sensitive(monitor_type != "default");
+#endif
+
+  debug_btn = Gtk::manage(new Gtk::Button(_("Debug monitoring")));
+  debug_btn->signal_clicked().connect(sigc::mem_fun(*this, &PreferencesDialog::on_debug_pressed));
+  panel->pack_start(*debug_btn, false, false, 0);
 
   return panel;
 }
 
-#endif
-
 Gtk::Widget *
 PreferencesDialog::create_mainwindow_page()
 {
@@ -597,7 +579,6 @@ PreferencesDialog::create_mainwindow_page()
   return new TimerBoxPreferencePage("main_window");
 }
 
-
 Gtk::Widget *
 PreferencesDialog::create_applet_page()
 {
@@ -605,7 +586,6 @@ PreferencesDialog::create_applet_page()
   return new TimerBoxPreferencePage("applet");
 }
 
-
 #ifdef HAVE_DISTRIBUTION
 Gtk::Widget *
 PreferencesDialog::create_network_page()
@@ -615,11 +595,9 @@ PreferencesDialog::create_network_page()
 #endif
 
 void
-PreferencesDialog::add_page(const char *label, const char *image,
-                            Gtk::Widget &widget)
+PreferencesDialog::add_page(const char *label, const char *image, Gtk::Widget &widget)
 {
-  string icon = Util::complete_directory(image, Util::SEARCH_PATH_IMAGES);
-  Glib::RefPtr<Gdk::Pixbuf> pixbuf = Gdk::Pixbuf::create_from_file(icon);
+  Glib::RefPtr<Gdk::Pixbuf> pixbuf = GtkUtil::create_pixbuf(image);
   notebook.add_page(label, pixbuf, widget);
 }
 
@@ -630,9 +608,7 @@ PreferencesDialog::on_sound_changed()
   SoundPlayer::set_enabled(idx > 0);
   if (idx > 0)
     {
-      SoundPlayer::Device dev = idx == 1
-        ? SoundPlayer::DEVICE_SOUNDCARD
-        : SoundPlayer::DEVICE_SPEAKER;
+      SoundPlayer::Device dev = idx == 1 ? SoundPlayer::DEVICE_SOUNDCARD : SoundPlayer::DEVICE_SPEAKER;
       SoundPlayer::set_device(dev);
     }
 
@@ -645,9 +621,7 @@ PreferencesDialog::update_senstives()
   int idx = sound_button->get_active_row_number();
   if (idx > 0)
     {
-      SoundPlayer::Device dev = idx == 1
-        ? SoundPlayer::DEVICE_SOUNDCARD
-        : SoundPlayer::DEVICE_SPEAKER;
+      SoundPlayer::Device dev = idx == 1 ? SoundPlayer::DEVICE_SOUNDCARD : SoundPlayer::DEVICE_SPEAKER;
 
       sound_treeview.set_sensitive(dev == SoundPlayer::DEVICE_SOUNDCARD);
       if (sound_theme_button != NULL)
@@ -688,7 +662,6 @@ PreferencesDialog::on_block_changed()
   GUIConfig::set_block_mode(m);
 }
 
-
 int
 PreferencesDialog::run()
 {
@@ -696,7 +669,6 @@ PreferencesDialog::run()
   return 0;
 }
 
-
 bool
 PreferencesDialog::on_focus_in_event(GdkEventFocus *event)
 {
@@ -710,58 +682,55 @@ PreferencesDialog::on_focus_in_event(GdkEventFocus *event)
       OperationMode mode = core->get_operation_mode();
       if (mode == OPERATION_MODE_NORMAL)
         {
-          core->set_operation_mode_override( OPERATION_MODE_QUIET, "preferences" );
+          core->set_operation_mode_override(OPERATION_MODE_QUIET, "preferences");
         }
     }
   TRACE_EXIT();
   return HigDialog::on_focus_in_event(event);
 }
 
-
 bool
 PreferencesDialog::on_focus_out_event(GdkEventFocus *event)
 {
   TRACE_ENTER("PreferencesDialog::focus_out");
   ICore *core = CoreFactory::get_core();
 
-  core->remove_operation_mode_override( "preferences" );
+  core->remove_operation_mode_override("preferences");
   TRACE_EXIT();
   return HigDialog::on_focus_out_event(event);
 }
 
-
 #if defined(HAVE_LANGUAGE_SELECTION)
 void
-PreferencesDialog::on_current_cell_data(const Gtk::TreeModel::const_iterator& iter)
+PreferencesDialog::on_current_cell_data(const Gtk::TreeModel::const_iterator &iter)
 {
   if (iter)
-  {
-    Gtk::TreeModel::Row row = *iter;
-    Glib::ustring name = row[languages_columns.current];
-    bool enabled = row[languages_columns.enabled];
+    {
+      Gtk::TreeModel::Row row = *iter;
+      Glib::ustring name = row[languages_columns.current];
+      bool enabled = row[languages_columns.enabled];
 
-    current_cellrenderer.set_property("text", name);
-    current_cellrenderer.set_property("sensitive", enabled);
-  }
+      current_cellrenderer.set_property("text", name);
+      current_cellrenderer.set_property("sensitive", enabled);
+    }
 }
 
 void
-PreferencesDialog::on_native_cell_data(const Gtk::TreeModel::const_iterator& iter)
+PreferencesDialog::on_native_cell_data(const Gtk::TreeModel::const_iterator &iter)
 {
   if (iter)
-  {
-    Gtk::TreeModel::Row row = *iter;
-    Glib::ustring name = row[languages_columns.native];
-    bool enabled = row[languages_columns.enabled];
+    {
+      Gtk::TreeModel::Row row = *iter;
+      Glib::ustring name = row[languages_columns.native];
+      bool enabled = row[languages_columns.enabled];
 
-    native_cellrenderer.set_property("text", name);
-    native_cellrenderer.set_property("sensitive", enabled);
-  }
+      native_cellrenderer.set_property("text", name);
+      native_cellrenderer.set_property("sensitive", enabled);
+    }
 }
 
 int
-PreferencesDialog::on_cell_data_compare(const Gtk::TreeModel::iterator& iter1,
-                                        const Gtk::TreeModel::iterator& iter2)
+PreferencesDialog::on_cell_data_compare(const Gtk::TreeModel::iterator &iter1, const Gtk::TreeModel::iterator &iter2)
 {
   Gtk::TreeModel::Row row1 = *iter1;
   Gtk::TreeModel::Row row2 = *iter2;
@@ -788,7 +757,7 @@ PreferencesDialog::on_cell_data_compare(const Gtk::TreeModel::iterator& iter1,
 void
 PreferencesDialog::on_autostart_toggled()
 {
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
   bool on = autostart_cb->get_active();
 
   gchar *value = NULL;
@@ -803,7 +772,7 @@ PreferencesDialog::on_autostart_toggled()
 #endif
 }
 
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
 void
 PreferencesDialog::on_monitor_type_toggled()
 {
@@ -826,12 +795,10 @@ PreferencesDialog::on_sound_enabled(const Glib::ustring &path_string)
       IGUI *gui = GUI::get_instance();
       SoundPlayer *snd = gui->get_sound_player();
 
-      snd->set_sound_enabled((SoundEvent)(int)row[sound_model.event],
-                             row[sound_model.enabled]);
+      snd->set_sound_enabled((SoundEvent)(int)row[sound_model.event], row[sound_model.enabled]);
     }
 }
 
-
 void
 PreferencesDialog::on_sound_play()
 {
@@ -840,17 +807,15 @@ PreferencesDialog::on_sound_play()
 
   if (iter)
     {
+      IGUI *gui = GUI::get_instance();
+      SoundPlayer *snd = gui->get_sound_player();
       Gtk::TreeModel::Row row = *iter;
 
       string filename;
-      bool valid = CoreFactory::get_configurator()->get_value(string(SoundPlayer::CFG_KEY_SOUND_EVENTS) +
-                                                              row[sound_model.label],
-                                                              filename);
+      bool valid = snd->get_sound_wav_file((SoundEvent)(int)row[sound_model.event], filename);
 
       if (valid && filename != "")
         {
-          IGUI *gui = GUI::get_instance();
-          SoundPlayer *snd = gui->get_sound_player();
           snd->play_sound(filename);
         }
     }
@@ -866,7 +831,6 @@ PreferencesDialog::on_sound_filechooser_play()
   snd->play_sound(filename);
 }
 
-
 void
 PreferencesDialog::on_sound_filechooser_select()
 {
@@ -882,24 +846,24 @@ PreferencesDialog::on_sound_filechooser_select()
       Glib::RefPtr<Gtk::TreeSelection> selection = sound_treeview.get_selection();
       Gtk::TreeModel::iterator iter = selection->get_selected();
 
-      if (iter) {
-        Gtk::TreeModel::Row row = *iter;
+      if (iter)
+        {
+          Gtk::TreeModel::Row row = *iter;
 
-        TRACE_MSG(row[sound_model.label]);
+          TRACE_MSG(row[sound_model.label]);
 
-        IGUI *gui = GUI::get_instance();
-        SoundPlayer *snd = gui->get_sound_player();
-        snd->set_sound_wav_file( (SoundEvent)(int)row[sound_model.event], filename);
-        TRACE_MSG(filename);
-        update_theme_selection();
-      }
+          IGUI *gui = GUI::get_instance();
+          SoundPlayer *snd = gui->get_sound_player();
+          snd->set_sound_wav_file((SoundEvent)(int)row[sound_model.event], filename);
+          TRACE_MSG(filename);
+          update_sound_theme_selection();
+        }
 
       fsbutton_filename = filename;
       TRACE_EXIT();
     }
 }
 
-
 void
 PreferencesDialog::on_sound_events_changed()
 {
@@ -911,12 +875,11 @@ PreferencesDialog::on_sound_events_changed()
     {
       Gtk::TreeModel::Row row = *iter;
 
-      string event = (Glib::ustring) row[sound_model.label];
-      string filename;
-      bool valid = CoreFactory::get_configurator()->get_value(string(SoundPlayer::CFG_KEY_SOUND_EVENTS) +
-                                                              row[sound_model.label],
-                                                              filename);
+      IGUI *gui = GUI::get_instance();
+      SoundPlayer *snd = gui->get_sound_player();
 
+      string filename;
+      bool valid = snd->get_sound_wav_file((SoundEvent)(int)row[sound_model.event], filename);
       TRACE_MSG(filename);
 
       if (valid && filename != "")
@@ -930,7 +893,6 @@ PreferencesDialog::on_sound_events_changed()
   TRACE_EXIT();
 }
 
-
 void
 PreferencesDialog::on_sound_theme_changed()
 {
@@ -951,16 +913,13 @@ PreferencesDialog::on_sound_theme_changed()
       if (iter)
         {
           Gtk::TreeModel::Row row = *iter;
-          string event = (Glib::ustring) row[sound_model.label];
+          string event = (Glib::ustring)row[sound_model.label];
           string filename;
-
-          bool valid = CoreFactory::get_configurator()->get_value(string(SoundPlayer::CFG_KEY_SOUND_EVENTS) +
-                                                                  row[sound_model.label],
-                                                                  filename);
+          bool valid = snd->get_sound_wav_file((SoundEvent)(int)row[sound_model.event], filename);
 
           if (valid && filename != "")
             {
-              TRACE_MSG(filename << " " <<row[sound_model.label]);
+              TRACE_MSG(filename << " " << row[sound_model.label]);
               inhibit_events++;
               fsbutton_filename = filename;
               fsbutton->set_filename(filename);
@@ -971,11 +930,10 @@ PreferencesDialog::on_sound_theme_changed()
   TRACE_EXIT();
 }
 
-
 void
-PreferencesDialog::update_theme_selection()
+PreferencesDialog::update_sound_theme_selection()
 {
-  TRACE_ENTER("PreferencesDialog::update_theme_selection");
+  TRACE_ENTER("PreferencesDialog::update_sound_theme_selection");
   sound_themes.erase(sound_themes.begin(), sound_themes.end());
 
   IGUI *gui = GUI::get_instance();
@@ -998,10 +956,98 @@ PreferencesDialog::update_theme_selection()
 #endif
 
       if (it->active)
-       {
+        {
           sound_theme_button->set_active(idx);
         }
       idx++;
     }
   TRACE_EXIT();
 }
+
+void
+PreferencesDialog::on_icon_theme_changed()
+{
+  TRACE_ENTER("PreferencesDialog::on_icon_theme_changed");
+  int idx = icon_theme_button->get_active_row_number();
+
+  if (idx == 0)
+    {
+      GUIConfig::set_icon_theme("");
+    }
+  else
+    {
+      GUIConfig::set_icon_theme(icon_theme_button->get_active_text());
+    }
+  TRACE_EXIT();
+}
+
+void
+PreferencesDialog::update_icon_theme_combo()
+{
+  TRACE_ENTER("PreferencesDialog::update_icon_theme_combo");
+  std::list<std::string> themes;
+
+  for (const auto &dirname: Util::get_search_path(Util::SEARCH_PATH_IMAGES))
+    {
+      if (!g_str_has_suffix(dirname.c_str(), "images"))
+        {
+          continue;
+        }
+
+      GDir *dir = g_dir_open(dirname.c_str(), 0, NULL);
+      if (dir != NULL)
+        {
+          const char *file;
+          while ((file = g_dir_read_name(dir)) != NULL)
+            {
+
+              gchar *test_path = g_build_filename(dirname.c_str(), file, NULL);
+              if (test_path != NULL && g_file_test(test_path, G_FILE_TEST_IS_DIR))
+                {
+                  themes.push_back(file);
+                }
+              g_free(test_path);
+            }
+          g_dir_close(dir);
+        }
+    }
+
+  if (themes.size() > 0)
+    {
+      icon_theme_button = Gtk::manage(new Gtk::ComboBoxText());
+
+#if GTKMM_CHECK_VERSION(2, 24, 0)
+      icon_theme_button->append(_("Default"));
+#else
+      icon_theme_button->append_text(_("Default"));
+#endif
+      icon_theme_button->set_active(0);
+
+      std::string current_icontheme = GUIConfig::get_icon_theme();
+      int idx = 1;
+      for (auto &theme: themes)
+        {
+#if GTKMM_CHECK_VERSION(2, 24, 0)
+          icon_theme_button->append(theme);
+#else
+          icon_theme_button->append_text(theme);
+#endif
+          if (current_icontheme == theme)
+            {
+              icon_theme_button->set_active(idx);
+            }
+          idx++;
+        }
+      icon_theme_button->signal_changed().connect(sigc::mem_fun(*this, &PreferencesDialog::on_icon_theme_changed));
+    }
+
+  TRACE_EXIT();
+}
+
+void
+PreferencesDialog::on_debug_pressed()
+{
+  IGUI *gui = GUI::get_instance();
+  Menus *menus = gui->get_menus();
+  menus->on_menu_debug();
+}
