@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
@@ -40,12 +40,11 @@
 #include "GUIConfig.hh"
 #include "TimerBoxControl.hh"
 
-
 //! Constructs the Applet Preference Notebook page.
-TimerBoxPreferencePage::TimerBoxPreferencePage(string n)
-  : Gtk::HBox(false, 6),
-    name(n),
-    ontop_cb(NULL)
+TimerBoxPreferencePage::TimerBoxPreferencePage(std::string n)
+  : Gtk::HBox(false, 6)
+  , name(n)
+  , ontop_cb(nullptr)
 {
   TRACE_ENTER("TimerBoxPreferencePage::TimerBoxPreferencePage");
 
@@ -68,7 +67,6 @@ TimerBoxPreferencePage::TimerBoxPreferencePage(string n)
   TRACE_EXIT();
 }
 
-
 //! Destructs the Applet Preference Notebook page.
 TimerBoxPreferencePage::~TimerBoxPreferencePage()
 {
@@ -80,13 +78,12 @@ TimerBoxPreferencePage::~TimerBoxPreferencePage()
   TRACE_EXIT();
 }
 
-
 //! Initializes all widgets.
 void
 TimerBoxPreferencePage::create_page()
 {
   // Placement
-  place_button  = Gtk::manage(new Gtk::ComboBoxText());
+  place_button = Gtk::manage(new Gtk::ComboBoxText());
 #if GTKMM_CHECK_VERSION(2, 24, 0)
   place_button->append(_("Place timers next to each other"));
   place_button->append(_("Place micro-break and rest break in one spot"));
@@ -105,13 +102,12 @@ TimerBoxPreferencePage::create_page()
   cycle_entry->set_increments(1, 10);
   cycle_entry->set_numeric(true);
   cycle_entry->set_width_chars(3);
-  cycle_entry->signal_changed().connect
-    (sigc::mem_fun(*this, &TimerBoxPreferencePage::on_cycle_time_changed));
+  cycle_entry->signal_changed().connect(sigc::mem_fun(*this, &TimerBoxPreferencePage::on_cycle_time_changed));
 
   // Timer display
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
-      Gtk::ComboBoxText *display_button  = Gtk::manage(new Gtk::ComboBoxText());
+      Gtk::ComboBoxText *display_button = Gtk::manage(new Gtk::ComboBoxText());
       timer_display_button[i] = display_button;
 
 #if GTKMM_CHECK_VERSION(2, 24, 0)
@@ -125,36 +121,25 @@ TimerBoxPreferencePage::create_page()
 #endif
     }
 
-  // Enabled/Disabled checkbox
-  Gtk::Label *enabled_lab = NULL;
+  HigCategoryPanel *hig = Gtk::manage(new HigCategoryPanel(_("Display")));
 
   if (name == "main_window")
     {
-      enabled_lab = Gtk::manage(GtkUtil::create_label(_("Show status window"), false));
-
       // Always-on-top
-      if (! GtkUtil::running_on_wayland())
+      if (!GtkUtil::running_on_wayland())
         {
-          ontop_cb = Gtk::manage
-            (new Gtk::CheckButton
-            (_("The status window stays always on top of other windows")));
+          ontop_cb = Gtk::manage(new Gtk::CheckButton(_("The status window stays always on top of other windows")));
           ontop_cb->signal_toggled().connect(sigc::mem_fun(*this, &TimerBoxPreferencePage::on_always_on_top_toggled));
           ontop_cb->set_active(GUIConfig::get_always_on_top());
         }
-    }
-  else if (name == "applet")
-    {
-      enabled_lab = Gtk::manage(GtkUtil::create_label(_("Applet enabled"), false));
+
+      Gtk::Label *enabled_lab = Gtk::manage(GtkUtil::create_label(_("Show status window"), false));
+      enabled_cb = Gtk::manage(new Gtk::CheckButton());
+      enabled_cb->add(*enabled_lab);
+      hig->add_widget(*enabled_cb);
     }
 
-  enabled_cb = Gtk::manage(new Gtk::CheckButton());
-  enabled_cb->add(*enabled_lab);
-
-  HigCategoryPanel *hig = Gtk::manage(new HigCategoryPanel(_("Display")));
-
-  hig->add_widget(*enabled_cb);
-
-  if (ontop_cb != NULL)
+  if (ontop_cb != nullptr)
     {
       hig->add_widget(*ontop_cb);
     }
@@ -169,12 +154,24 @@ TimerBoxPreferencePage::create_page()
   hig->add_label(_("Rest break:"), *timer_display_button[1]);
   hig->add_label(_("Daily limit:"), *timer_display_button[2]);
 
+  if (name == "applet")
+    {
+      Gtk::Label *applet_fallback_enabled_lab = Gtk::manage(GtkUtil::create_label(_("Fallback applet enabled"), false));
+      applet_fallback_enabled_cb = Gtk::manage(new Gtk::CheckButton());
+      applet_fallback_enabled_cb->add(*applet_fallback_enabled_lab);
+      hig->add_widget(*applet_fallback_enabled_cb);
+
+      Gtk::Label *applet_icon_enabled_lab = Gtk::manage(GtkUtil::create_label(_("Show status icon"), false));
+      applet_icon_enabled_cb = Gtk::manage(new Gtk::CheckButton());
+      applet_icon_enabled_cb->add(*applet_icon_enabled_lab);
+      hig->add_widget(*applet_icon_enabled_cb);
+    }
+
   pack_end(*hig, true, true, 0);
 
   set_border_width(12);
 }
 
-
 //! Retrieves the applet configuration and sets the widgets.
 void
 TimerBoxPreferencePage::init_page_values()
@@ -201,10 +198,9 @@ TimerBoxPreferencePage::init_page_values()
     }
   place_button->set_active(place);
 
-
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
-      int flags = TimerBoxControl::get_timer_flags(name, (BreakId) i);
+      int flags = TimerBoxControl::get_timer_flags(name, (BreakId)i);
       int showhide;
       if (flags & TimerBoxControl::BREAK_HIDE)
         {
@@ -222,23 +218,45 @@ TimerBoxPreferencePage::init_page_values()
     }
   cycle_entry->set_value(TimerBoxControl::get_cycle_time(name));
 
-  enabled_cb->set_active(TimerBoxControl::is_enabled(name));
+  if (enabled_cb != nullptr)
+    {
+      enabled_cb->set_active(TimerBoxControl::is_enabled(name));
+    }
+
+  if (name == "applet")
+    {
+      applet_fallback_enabled_cb->set_active(GUIConfig::is_applet_fallback_enabled());
+      applet_icon_enabled_cb->set_active(GUIConfig::is_applet_icon_enabled());
+    }
+
   enable_buttons();
 }
 
-
 void
 TimerBoxPreferencePage::init_page_callbacks()
 {
-  place_button->signal_changed().connect
-    (sigc::mem_fun(*this, &TimerBoxPreferencePage::on_place_changed));
+  place_button->signal_changed().connect(sigc::mem_fun(*this, &TimerBoxPreferencePage::on_place_changed));
 
-  enabled_cb->signal_toggled().connect(sigc::mem_fun(*this, &TimerBoxPreferencePage::on_enabled_toggled));
+  if (enabled_cb != nullptr)
+    {
+      enabled_cb->signal_toggled().connect(sigc::mem_fun(*this, &TimerBoxPreferencePage::on_enabled_toggled));
+    }
+
+  if (applet_fallback_enabled_cb != nullptr)
+    {
+      applet_fallback_enabled_cb->signal_toggled().connect(
+        sigc::mem_fun(*this, &TimerBoxPreferencePage::on_applet_fallback_enabled_toggled));
+    }
+
+  if (applet_icon_enabled_cb != nullptr)
+    {
+      applet_icon_enabled_cb->signal_toggled().connect(
+        sigc::mem_fun(*this, &TimerBoxPreferencePage::on_applet_icon_enabled_toggled));
+    }
 
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
-      timer_display_button[i]->signal_changed().connect
-        (bind(sigc::mem_fun(*this, &TimerBoxPreferencePage::on_display_changed), i));
+      timer_display_button[i]->signal_changed().connect(bind(sigc::mem_fun(*this, &TimerBoxPreferencePage::on_display_changed), i));
     }
 }
 
@@ -253,6 +271,19 @@ TimerBoxPreferencePage::on_enabled_toggled()
   enable_buttons();
 }
 
+void
+TimerBoxPreferencePage::on_applet_fallback_enabled_toggled()
+{
+  bool on = applet_fallback_enabled_cb->get_active();
+  GUIConfig::set_applet_fallback_enabled(on);
+}
+
+void
+TimerBoxPreferencePage::on_applet_icon_enabled_toggled()
+{
+  bool on = applet_icon_enabled_cb->get_active();
+  GUIConfig::set_applet_icon_enabled(on);
+}
 
 //! The placement is changed.
 void
@@ -290,12 +321,10 @@ TimerBoxPreferencePage::on_place_changed()
 
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
-      TimerBoxControl::set_timer_slot(name, (BreakId) i, slots[i]);
+      TimerBoxControl::set_timer_slot(name, (BreakId)i, slots[i]);
     }
-
 }
 
-
 //! The display of the specified break is changed.
 void
 TimerBoxPreferencePage::on_display_changed(int break_id)
@@ -314,15 +343,14 @@ TimerBoxPreferencePage::on_display_changed(int break_id)
       flags = TimerBoxControl::BREAK_WHEN_FIRST;
       break;
     }
-  TimerBoxControl::set_timer_flags(name, (BreakId) break_id, flags);
+  TimerBoxControl::set_timer_flags(name, (BreakId)break_id, flags);
 
   enable_buttons();
 }
 
-
 //! Enable widgets
 void
-TimerBoxPreferencePage::enable_buttons(void)
+TimerBoxPreferencePage::enable_buttons()
 {
   int count = 0;
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
@@ -335,9 +363,7 @@ TimerBoxPreferencePage::enable_buttons(void)
 
   if (name == "applet")
     {
-      bool on = enabled_cb->get_active();
-
-      place_button->set_sensitive(on && count != 3);
+      place_button->set_sensitive(count != 3);
       for (int i = 0; i < BREAK_ID_SIZEOF; i++)
         {
           ICore *core = CoreFactory::get_core();
@@ -346,10 +372,9 @@ TimerBoxPreferencePage::enable_buttons(void)
           IBreak *b = core->get_break(BreakId(i));
 
           bool timer_on = b->is_enabled();
-          timer_display_button[i]->set_sensitive(on && timer_on);
+          timer_display_button[i]->set_sensitive(timer_on);
         }
-      cycle_entry->set_sensitive(on && count != 3);
-
+      cycle_entry->set_sensitive(count != 3);
     }
   else if (name == "main_window")
     {
@@ -379,23 +404,20 @@ TimerBoxPreferencePage::enable_buttons(void)
     }
 }
 
-
 //! The applet cycle time has been changed.
 void
 TimerBoxPreferencePage::on_cycle_time_changed()
 {
-  int value = (int) cycle_entry->get_value();
+  int value = (int)cycle_entry->get_value();
   TimerBoxControl::set_cycle_time(name, value);
 }
 
-
 void
 TimerBoxPreferencePage::on_always_on_top_toggled()
 {
   GUIConfig::set_always_on_top(ontop_cb->get_active());
 }
 
-
 void
 TimerBoxPreferencePage::config_changed_notify(const string &key)
 {
