@@ -18,24 +18,24 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
 
 #if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
 #  include <sys/time.h>
-# else
 #  include <time.h>
-# endif
+#else
+#  if HAVE_SYS_TIME_H
+#    include <sys/time.h>
+#  else
+#    include <time.h>
+#  endif
 #endif
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#  include <unistd.h>
 #endif
 #include <assert.h>
 #include <sstream>
@@ -59,13 +59,13 @@
 #include "Locale.hh"
 
 StatisticsDialog::StatisticsDialog()
-  : HigDialog(_("Statistics"), false, false),
-    statistics(NULL),
-    daily_usage_time_label(NULL),
-    weekly_usage_time_label(NULL),
-    monthly_usage_time_label(NULL),
-    date_label(NULL),
-    update_usage_real_time(false)
+  : HigDialog(_("Statistics"), false, false)
+  , statistics(NULL)
+  , daily_usage_time_label(NULL)
+  , weekly_usage_time_label(NULL)
+  , monthly_usage_time_label(NULL)
+  , date_label(NULL)
+  , update_usage_real_time(false)
 {
   ICore *core = CoreFactory::get_core();
   statistics = core->get_statistics();
@@ -79,12 +79,8 @@ StatisticsDialog::StatisticsDialog()
   display_calendar_date();
 }
 
-
 //! Destructor.
-StatisticsDialog::~StatisticsDialog()
-{
-}
-
+StatisticsDialog::~StatisticsDialog() {}
 
 int
 StatisticsDialog::run()
@@ -96,15 +92,14 @@ StatisticsDialog::run()
   return 0;
 }
 
-
 void
 StatisticsDialog::init_gui()
 {
-#if !defined(PLATFORM_OS_OSX)
+#if !defined(PLATFORM_OS_MACOS)
   Gtk::Notebook *tnotebook = Gtk::manage(new Gtk::Notebook());
   tnotebook->set_tab_pos(Gtk::POS_TOP);
 #else
-  Gtk::HBox *tnotebook= Gtk::manage(new Gtk::HBox(false, 6));
+  Gtk::HBox *tnotebook = Gtk::manage(new Gtk::HBox(false, 6));
 #endif
 
   // Calendar
@@ -112,33 +107,21 @@ StatisticsDialog::init_gui()
   calendar->signal_month_changed().connect(sigc::mem_fun(*this, &StatisticsDialog::on_calendar_month_changed));
   calendar->signal_day_selected().connect(sigc::mem_fun(*this, &StatisticsDialog::on_calendar_day_selected));
 #ifdef HAVE_GTK3
-  calendar->set_display_options(Gtk::CALENDAR_SHOW_WEEK_NUMBERS
-                                |Gtk::CALENDAR_SHOW_DAY_NAMES
-                                |Gtk::CALENDAR_SHOW_HEADING);
+  calendar->set_display_options(Gtk::CALENDAR_SHOW_WEEK_NUMBERS | Gtk::CALENDAR_SHOW_DAY_NAMES | Gtk::CALENDAR_SHOW_HEADING);
 #else
-  calendar->display_options(Gtk::CALENDAR_SHOW_WEEK_NUMBERS
-                            |Gtk::CALENDAR_SHOW_DAY_NAMES
-                            |Gtk::CALENDAR_SHOW_HEADING);
+  calendar->display_options(Gtk::CALENDAR_SHOW_WEEK_NUMBERS | Gtk::CALENDAR_SHOW_DAY_NAMES | Gtk::CALENDAR_SHOW_HEADING);
 #endif
 
   // Button box.
-  Gtk::HBox *btnbox= Gtk::manage(new Gtk::HBox(false, 6));
-  first_btn
-    = Gtk::manage(GtkUtil::create_custom_stock_button(NULL,Gtk::Stock::GOTO_FIRST));
-  first_btn->signal_clicked()
-    .connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_goto_first));
-  last_btn
-    = Gtk::manage(GtkUtil::create_custom_stock_button(NULL,Gtk::Stock::GOTO_LAST));
-  last_btn->signal_clicked()
-    .connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_goto_last));
-  back_btn
-    = Gtk::manage(GtkUtil::create_custom_stock_button(NULL,Gtk::Stock::GO_BACK));
-  back_btn->signal_clicked()
-    .connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_go_back));
-  forward_btn
-    = Gtk::manage(GtkUtil::create_custom_stock_button(NULL,Gtk::Stock::GO_FORWARD));
-  forward_btn->signal_clicked()
-    .connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_go_forward));
+  Gtk::HBox *btnbox = Gtk::manage(new Gtk::HBox(false, 6));
+  first_btn = Gtk::manage(GtkUtil::create_custom_stock_button(NULL, Gtk::Stock::GOTO_FIRST));
+  first_btn->signal_clicked().connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_goto_first));
+  last_btn = Gtk::manage(GtkUtil::create_custom_stock_button(NULL, Gtk::Stock::GOTO_LAST));
+  last_btn->signal_clicked().connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_goto_last));
+  back_btn = Gtk::manage(GtkUtil::create_custom_stock_button(NULL, Gtk::Stock::GO_BACK));
+  back_btn->signal_clicked().connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_go_back));
+  forward_btn = Gtk::manage(GtkUtil::create_custom_stock_button(NULL, Gtk::Stock::GO_FORWARD));
+  forward_btn->signal_clicked().connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_go_forward));
 
   btnbox->pack_start(*first_btn, true, true, 0);
   btnbox->pack_start(*back_btn, true, true, 0);
@@ -149,15 +132,14 @@ StatisticsDialog::init_gui()
   date_label = Gtk::manage(new Gtk::Label);
 
   // Navigation box
-  HigCategoryPanel *browsebox
-    = Gtk::manage(new HigCategoryPanel(_("Browse history")));
+  HigCategoryPanel *browsebox = Gtk::manage(new HigCategoryPanel(_("Browse history")));
   browsebox->add_widget(*btnbox);
   browsebox->add_widget(*calendar);
 
   // Delete button
-  delete_btn = Gtk::manage( GtkUtil::create_custom_stock_button( _("Delete all statistics history"), Gtk::Stock::DELETE ) );
-  delete_btn->signal_clicked().connect( sigc::mem_fun( *this, &StatisticsDialog::on_history_delete_all ) );
-  browsebox->add_widget( *delete_btn );
+  delete_btn = Gtk::manage(GtkUtil::create_custom_stock_button(_("Delete all statistics history"), Gtk::Stock::DELETE));
+  delete_btn->signal_clicked().connect(sigc::mem_fun(*this, &StatisticsDialog::on_history_delete_all));
+  browsebox->add_widget(*delete_btn);
 
   // Stats box
   HigCategoriesPanel *navbox = Gtk::manage(new HigCategoriesPanel());
@@ -171,14 +153,14 @@ StatisticsDialog::init_gui()
   hbox->pack_start(*navbox, true, true, 0);
 
   create_break_page(tnotebook);
-#if !defined(PLATFORM_OS_OSX)
+#if !defined(PLATFORM_OS_MACOS)
   // No details activity statistics on OS X..
   create_activity_page(tnotebook);
 #endif
 
   tnotebook->show_all();
 
-#if !defined(PLATFORM_OS_OSX)
+#if !defined(PLATFORM_OS_MACOS)
   tnotebook->set_current_page(0);
 #endif
 
@@ -201,61 +183,35 @@ StatisticsDialog::create_break_page(Gtk::Widget *tnotebook)
   table->set_col_spacings(6);
   table->set_border_width(6);
 
-  Gtk::Widget *unique_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Break prompts"),
-     _("The number of times you were prompted to break, excluding"
-       " repeated prompts for the same break"));
+  Gtk::Widget *unique_label = GtkUtil::create_label_with_tooltip(_("Break prompts"),
+                                                                 _("The number of times you were prompted to break, excluding"
+                                                                   " repeated prompts for the same break"));
 
-  Gtk::Widget *prompted_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Repeated prompts"),
-     _("The number of times you were repeatedly prompted to break"));
+  Gtk::Widget *prompted_label =
+    GtkUtil::create_label_with_tooltip(_("Repeated prompts"), _("The number of times you were repeatedly prompted to break"));
 
-  Gtk::Widget *taken_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Prompted breaks taken"),
-     _("The number of times you took a break when being prompted"));
+  Gtk::Widget *taken_label =
+    GtkUtil::create_label_with_tooltip(_("Prompted breaks taken"), _("The number of times you took a break when being prompted"));
 
-  Gtk::Widget *natural_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Natural breaks taken"),
-     _("The number of times you took a break without being prompted"));
+  Gtk::Widget *natural_label =
+    GtkUtil::create_label_with_tooltip(_("Natural breaks taken"), _("The number of times you took a break without being prompted"));
 
-  Gtk::Widget *skipped_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Breaks skipped"),
-     _("The number of breaks you skipped"));
+  Gtk::Widget *skipped_label = GtkUtil::create_label_with_tooltip(_("Breaks skipped"), _("The number of breaks you skipped"));
 
-  Gtk::Widget *postponed_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Breaks postponed"),
-     _("The number of breaks you postponed"));
+  Gtk::Widget *postponed_label = GtkUtil::create_label_with_tooltip(_("Breaks postponed"), _("The number of breaks you postponed"));
 
-  Gtk::Widget *overdue_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Overdue time"),
-     _("The total time this break was overdue"));
+  Gtk::Widget *overdue_label = GtkUtil::create_label_with_tooltip(_("Overdue time"), _("The total time this break was overdue"));
 
-  Gtk::Widget *usage_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Usage"),
-     _("Active computer usage"));
+  Gtk::Widget *usage_label = GtkUtil::create_label_with_tooltip(_("Usage"), _("Active computer usage"));
 
-  Gtk::Widget *daily_usage_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Daily"),
-     _("The total computer usage for the selected day"));
+  Gtk::Widget *daily_usage_label =
+    GtkUtil::create_label_with_tooltip(_("Daily"), _("The total computer usage for the selected day"));
 
-  Gtk::Widget *weekly_usage_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Weekly"),
-     _("The total computer usage for the whole week of the selected day"));
+  Gtk::Widget *weekly_usage_label =
+    GtkUtil::create_label_with_tooltip(_("Weekly"), _("The total computer usage for the whole week of the selected day"));
 
-  Gtk::Widget *monthly_usage_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Monthly"),
-     _("The total computer usage for the whole month of the selected day"));
+  Gtk::Widget *monthly_usage_label =
+    GtkUtil::create_label_with_tooltip(_("Monthly"), _("The total computer usage for the whole month of the selected day"));
 
   Gtk::HSeparator *hrule = Gtk::manage(new Gtk::HSeparator());
   Gtk::VSeparator *vrule = Gtk::manage(new Gtk::VSeparator());
@@ -263,12 +219,9 @@ StatisticsDialog::create_break_page(Gtk::Widget *tnotebook)
   // Add labels to table.
   int y = 0;
 
-  Gtk::Widget *mp_label = Gtk::manage(GtkUtil::create_label_for_break
-                                 (BREAK_ID_MICRO_BREAK));
-  Gtk::Widget *rb_label = Gtk::manage(GtkUtil::create_label_for_break
-                                 (BREAK_ID_REST_BREAK));
-  Gtk::Widget *dl_label = Gtk::manage(GtkUtil::create_label_for_break
-                                 (BREAK_ID_DAILY_LIMIT));
+  Gtk::Widget *mp_label = Gtk::manage(GtkUtil::create_label_for_break(BREAK_ID_MICRO_BREAK));
+  Gtk::Widget *rb_label = Gtk::manage(GtkUtil::create_label_for_break(BREAK_ID_REST_BREAK));
+  Gtk::Widget *dl_label = Gtk::manage(GtkUtil::create_label_for_break(BREAK_ID_DAILY_LIMIT));
 
   y = 0;
   GtkUtil::table_attach_left_aligned(*table, *mp_label, 2, y);
@@ -312,7 +265,6 @@ StatisticsDialog::create_break_page(Gtk::Widget *tnotebook)
   GtkUtil::table_attach_right_aligned(*table, *weekly_usage_time_label, 3, y);
   GtkUtil::table_attach_right_aligned(*table, *monthly_usage_time_label, 4, y);
 
-
   // Put the breaks in table.
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
@@ -325,18 +277,17 @@ StatisticsDialog::create_break_page(Gtk::Widget *tnotebook)
 
   box->show_all();
 
-#if !defined(PLATFORM_OS_OSX)
-  #ifdef HAVE_GTK3
+#if !defined(PLATFORM_OS_MACOS)
+#  ifdef HAVE_GTK3
   ((Gtk::Notebook *)tnotebook)->append_page(*table, *box);
-  #else
+#  else
   ((Gtk::Notebook *)tnotebook)->pages().push_back(Gtk::Notebook_Helpers::TabElem(*table, *box));
-  #endif
+#  endif
 #else
   ((Gtk::HBox *)tnotebook)->pack_start(*table, true, true, 0);
 #endif
 }
 
-
 void
 StatisticsDialog::create_activity_page(Gtk::Widget *tnotebook)
 {
@@ -349,28 +300,17 @@ StatisticsDialog::create_activity_page(Gtk::Widget *tnotebook)
   table->set_col_spacings(6);
   table->set_border_width(6);
 
-  Gtk::Widget *mouse_time_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Mouse usage:"),
-     _("The total time you were using the mouse"));
-  Gtk::Widget *mouse_movement_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Mouse movement:"),
-     _("The total on-screen mouse movement"));
-  Gtk::Widget *mouse_click_movement_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Effective mouse movement:"),
-     _("The total mouse movement you would have had if you moved your "
-       "mouse in straight lines between clicks"));
-  Gtk::Widget *mouse_clicks_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Mouse button clicks:"),
-     _("The total number of mouse button clicks"));
-  Gtk::Widget *keystrokes_label
-    = GtkUtil::create_label_with_tooltip
-    (_("Keystrokes:"),
-     _("The total number of keys pressed"));
-
+  Gtk::Widget *mouse_time_label =
+    GtkUtil::create_label_with_tooltip(_("Mouse usage:"), _("The total time you were using the mouse"));
+  Gtk::Widget *mouse_movement_label =
+    GtkUtil::create_label_with_tooltip(_("Mouse movement:"), _("The total on-screen mouse movement"));
+  Gtk::Widget *mouse_click_movement_label =
+    GtkUtil::create_label_with_tooltip(_("Effective mouse movement:"),
+                                       _("The total mouse movement you would have had if you moved your "
+                                         "mouse in straight lines between clicks"));
+  Gtk::Widget *mouse_clicks_label =
+    GtkUtil::create_label_with_tooltip(_("Mouse button clicks:"), _("The total number of mouse button clicks"));
+  Gtk::Widget *keystrokes_label = GtkUtil::create_label_with_tooltip(_("Keystrokes:"), _("The total number of keys pressed"));
 
   int y = 0;
   GtkUtil::table_attach_left_aligned(*table, *mouse_time_label, 0, y++);
@@ -393,7 +333,6 @@ StatisticsDialog::create_activity_page(Gtk::Widget *tnotebook)
 #endif
 }
 
-
 void
 StatisticsDialog::display_statistics(IStatistics::DailyStats *stats)
 {
@@ -423,7 +362,6 @@ StatisticsDialog::display_statistics(IStatistics::DailyStats *stats)
       date_label->set_text(buf);
     }
 
-
   int64_t value = stats->misc_stats[IStatistics::STATS_VALUE_TOTAL_ACTIVE_TIME];
   daily_usage_time_label->set_text(Text::time_to_string(value));
 
@@ -437,8 +375,7 @@ StatisticsDialog::display_statistics(IStatistics::DailyStats *stats)
       ss << value;
       break_labels[i][0]->set_text(ss.str());
 
-      value = stats->break_stats[i][IStatistics::STATS_BREAKVALUE_PROMPTED]
-        - value;
+      value = stats->break_stats[i][IStatistics::STATS_BREAKVALUE_PROMPTED] - value;
       ss.str("");
       ss << value;
       break_labels[i][1]->set_text(ss.str());
@@ -475,9 +412,10 @@ StatisticsDialog::display_statistics(IStatistics::DailyStats *stats)
       // Label not available is OS X
 
       value = stats->misc_stats[IStatistics::STATS_VALUE_TOTAL_MOVEMENT_TIME];
-      if (value > 24 * 60 * 60) {
-        value = 0;
-      }
+      if (value > 24 * 60 * 60)
+        {
+          value = 0;
+        }
       activity_labels[0]->set_text(Text::time_to_string(value));
 
       value = stats->misc_stats[IStatistics::STATS_VALUE_TOTAL_MOUSE_MOVEMENT];
@@ -500,7 +438,6 @@ StatisticsDialog::display_statistics(IStatistics::DailyStats *stats)
       ss << value;
       activity_labels[4]->set_text(ss.str());
     }
-
 }
 
 void
@@ -530,9 +467,7 @@ StatisticsDialog::display_week_statistics()
       time_loc = std::localtime(&t);
 
       int idx, next, prev;
-      statistics->get_day_index_by_date(time_loc->tm_year + 1900,
-                                        time_loc->tm_mon + 1,
-                                        time_loc->tm_mday, idx, next, prev);
+      statistics->get_day_index_by_date(time_loc->tm_year + 1900, time_loc->tm_mon + 1, time_loc->tm_mday, idx, next, prev);
 
       if (idx >= 0)
         {
@@ -550,7 +485,8 @@ StatisticsDialog::display_week_statistics()
 }
 
 void
-StatisticsDialog::display_month_statistics() {
+StatisticsDialog::display_month_statistics()
+{
   guint y, m, d;
   calendar->get_date(y, m, d);
 
@@ -638,14 +574,14 @@ StatisticsDialog::get_calendar_day_index(int &idx, int &next, int &prev)
 {
   guint y, m, d;
   calendar->get_date(y, m, d);
-  statistics->get_day_index_by_date(y, m+1, d, idx, next, prev);
+  statistics->get_day_index_by_date(y, m + 1, d, idx, next, prev);
 }
 
 void
 StatisticsDialog::set_calendar_day_index(int idx)
 {
   IStatistics::DailyStats *stats = statistics->get_day(idx);
-  calendar->select_month(stats->start.tm_mon, stats->start.tm_year+1900);
+  calendar->select_month(stats->start.tm_mon, stats->start.tm_year + 1900);
   calendar->select_day(stats->start.tm_mday);
   display_calendar_date();
 }
@@ -683,7 +619,6 @@ StatisticsDialog::on_history_go_back()
     set_calendar_day_index(prev);
 }
 
-
 void
 StatisticsDialog::on_history_go_forward()
 {
@@ -693,14 +628,12 @@ StatisticsDialog::on_history_go_forward()
     set_calendar_day_index(next);
 }
 
-
 void
 StatisticsDialog::on_history_goto_last()
 {
   set_calendar_day_index(0);
 }
 
-
 void
 StatisticsDialog::on_history_goto_first()
 {
@@ -708,63 +641,54 @@ StatisticsDialog::on_history_goto_first()
   set_calendar_day_index(size);
 }
 
-
 void
 StatisticsDialog::on_history_delete_all()
 {
-    /* Modal dialogs interrupt GUI input. That can be a problem if for example a break is
-    triggered while the message boxes are shown. The user would have no way to interact
-    with the break window without closing out the dialog which may be hidden behind it.
-    Temporarily override operation mode to avoid catastrophe, and remove the
-    override before any return.
-    */
-    const char funcname[] = "StatisticsDialog::on_history_delete_all";
-    CoreFactory::get_core()->set_operation_mode_override( OPERATION_MODE_SUSPENDED, funcname );
+  /* Modal dialogs interrupt GUI input. That can be a problem if for example a break is
+  triggered while the message boxes are shown. The user would have no way to interact
+  with the break window without closing out the dialog which may be hidden behind it.
+  Temporarily override operation mode to avoid catastrophe, and remove the
+  override before any return.
+  */
+  const char funcname[] = "StatisticsDialog::on_history_delete_all";
+  CoreFactory::get_core()->set_operation_mode_override(OPERATION_MODE_SUSPENDED, funcname);
 
-    // Confirm the user's intention
-    string msg = HigUtil::create_alert_text(
-        _("Warning"),
-        _("You have chosen to delete your statistics history. Continue?")
-        );
-    Gtk::MessageDialog mb_ask( *this, msg, true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_YES_NO, false );
-    mb_ask.set_title( _("Warning") );
-    mb_ask.get_widget_for_response( Gtk::RESPONSE_NO )->grab_default();
-    if( mb_ask.run() == Gtk::RESPONSE_YES )
+  // Confirm the user's intention
+  string msg = HigUtil::create_alert_text(_("Warning"), _("You have chosen to delete your statistics history. Continue?"));
+  Gtk::MessageDialog mb_ask(*this, msg, true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_YES_NO, false);
+  mb_ask.set_title(_("Warning"));
+  mb_ask.get_widget_for_response(Gtk::RESPONSE_NO)->grab_default();
+  if (mb_ask.run() == Gtk::RESPONSE_YES)
     {
-        mb_ask.hide();
+      mb_ask.hide();
 
-        // Try to delete statistics history files
-        for( ;; )
+      // Try to delete statistics history files
+      for (;;)
         {
-            if( statistics->delete_all_history() )
+          if (statistics->delete_all_history())
             {
-                msg = HigUtil::create_alert_text(
-                    _("Files deleted!"),
-                    _("The files containing your statistics history have been deleted.")
-                    );
-                Gtk::MessageDialog mb_info( *this, msg, true, Gtk::MESSAGE_INFO, Gtk::BUTTONS_OK, false );
-                mb_info.set_title( _("Info") );
-                mb_info.run();
-                break;
+              msg = HigUtil::create_alert_text(_("Files deleted!"),
+                                               _("The files containing your statistics history have been deleted."));
+              Gtk::MessageDialog mb_info(*this, msg, true, Gtk::MESSAGE_INFO, Gtk::BUTTONS_OK, false);
+              mb_info.set_title(_("Info"));
+              mb_info.run();
+              break;
             }
 
-            msg = HigUtil::create_alert_text(
-                _("File deletion failed!"),
-                _("The files containing your statistics history could not be deleted. Try again?")
-                );
-            Gtk::MessageDialog mb_error( *this, msg, true, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_YES_NO, false );
-            mb_error.set_title( _("Error") );
-            mb_error.get_widget_for_response( Gtk::RESPONSE_NO )->grab_default();
-            if( mb_error.run() != Gtk::RESPONSE_YES )
-                break;
+          msg = HigUtil::create_alert_text(_("File deletion failed!"),
+                                           _("The files containing your statistics history could not be deleted. Try again?"));
+          Gtk::MessageDialog mb_error(*this, msg, true, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_YES_NO, false);
+          mb_error.set_title(_("Error"));
+          mb_error.get_widget_for_response(Gtk::RESPONSE_NO)->grab_default();
+          if (mb_error.run() != Gtk::RESPONSE_YES)
+            break;
         }
     }
 
-    // Remove this function's operation mode override
-    CoreFactory::get_core()->remove_operation_mode_override( funcname );
+  // Remove this function's operation mode override
+  CoreFactory::get_core()->remove_operation_mode_override(funcname);
 }
 
-
 //! Periodic heartbeat.
 bool
 StatisticsDialog::on_timer()
@@ -777,16 +701,13 @@ StatisticsDialog::on_timer()
   return true;
 }
 
-
 void
 StatisticsDialog::stream_distance(stringstream &stream, int64_t pixels)
 {
   char buf[64];
   GdkRectangle rec;
 
-  // TODO: for now take monitor 0...
-
-#if GTK_CHECK_VERSION (3, 22, 0)
+#if GTK_CHECK_VERSION(3, 22, 0)
   GdkMonitor *monitor = gdk_display_get_monitor(gdk_display_get_default(), 0);
   gdk_monitor_get_geometry(monitor, &rec);
 #else
@@ -794,13 +715,13 @@ StatisticsDialog::stream_distance(stringstream &stream, int64_t pixels)
   gdk_screen_get_monitor_geometry(screen, 0, &rec);
 #endif
 
-#if GTK_CHECK_VERSION (3, 22, 0)
-  double width_mm = gdk_monitor_get_width_mm (monitor);
-#elif GTK_CHECK_VERSION (2, 14, 0)
-  double width_mm = gdk_screen_get_monitor_width_mm (screen, 0);
+#if GTK_CHECK_VERSION(3, 22, 0)
+  double width_mm = gdk_monitor_get_width_mm(monitor);
+#elif GTK_CHECK_VERSION(2, 14, 0)
+  double width_mm = gdk_screen_get_monitor_width_mm(screen, 0);
 #endif
 
-  double mm = (double) pixels * width_mm / rec.width;
-  sprintf(buf, "%.02f m", mm/1000);
+  double mm = (double)pixels * width_mm / rec.width;
+  sprintf(buf, "%.02f m", mm / 1000);
   stream << buf;
 }
